/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03393
 |               DRUG SERVICES RESEARCH SURVEY (DSRS), 1990
 |         (DATASET 0001: PHASE I - FACILITY TELEPHONE INTERVIEW)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03393-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE obs_num   -4='(-4) NOT MASTER FACILITY' ;
  VALUE crp_mo1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) JANUARY' 2='(2) FEBRUARY' 3='(3) MARCH'
                  4='(4) APRIL' 5='(5) MAY' 6='(6) JUNE' 7='(7) JULY' 8='(8) AUGUST'
                  9='(9) SEPTEMBER' 10='(10) OCTOBER' 11='(11) NOVEMBER' 12='(12) DECEMBER' ;
  VALUE crp_da1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE crp_yr1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE crp_mo2f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) JANUARY' 2='(2) FEBRUARY' 3='(3) MARCH'
                  4='(4) APRIL' 5='(5) MAY' 6='(6) JUNE' 7='(7) JULY' 8='(8) AUGUST'
                  9='(9) SEPTEMBER' 10='(10) OCTOBER' 11='(11) NOVEMBER' 12='(12) DECEMBER' ;
  VALUE crp_da2f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE crp_yr2f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE clength   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE frp_mo1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) JANUARY' 2='(2) FEBRUARY' 3='(3) MARCH'
                  4='(4) APRIL' 5='(5) MAY' 6='(6) JUNE' 7='(7) JULY' 8='(8) AUGUST'
                  9='(9) SEPTEMBER' 10='(10) OCTOBER' 11='(11) NOVEMBER' 12='(12) DECEMBER' ;
  VALUE frp_da1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE frp_yr1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE frp_mo2f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) JANUARY' 2='(2) FEBRUARY' 3='(3) MARCH'
                  4='(4) APRIL' 5='(5) MAY' 6='(6) JUNE' 7='(7) JULY' 8='(8) AUGUST'
                  9='(9) SEPTEMBER' 10='(10) OCTOBER' 11='(11) NOVEMBER' 12='(12) DECEMBER' ;
  VALUE frp_da2f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE frp_yr2f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE flength   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a1_no     -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a1_unit   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) MONTHS' 2='(2) YEARS' ;
  VALUE a2a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a2b       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a2c       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a2d       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a2e       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a3a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a3b       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a3c       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a3d       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a3e       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a4a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a4b       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a4c       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a4d       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a4e       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a4f       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a5a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE a5b       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE hidd_a6f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE hidm_a6f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE hidf_a6f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE rsdd_a6f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE rsdm_a6f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE rsdf_a6f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE opdd_a6f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE opdm_a6f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE opdf_a6f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE alc_a6ff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE corrfac   -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE alchonly  -4='(-4) NOT MASTER FACILITY' 0='(0) NO' 1='(1) YES' ;
  VALUE seq11cnt  -4='(-4) NOT MASTER FACILITY' ;
  VALUE seq12cnt  -4='(-4) NOT MASTER FACILITY' ;
  VALUE nummod    -4='(-4) NOT MASTER FACILITY' ;
  VALUE mod       -4='(-4) NOT MASTER FACILITY' 1='(1) HOSPITAL INPATIENT DRUG DETOX'
                  2='(2) HOSPITAL INPATIENT DRUG FREE' 3='(3) RESIDENTIAL DRUG DETOX'
                  4='(4) RESIDENTIAL DRUG FREE' 5='(5) OUTPATIENT DRUG DETOX'
                  6='(6) OUTPATIENT DRUG MAINTENANCE' 7='(7) OUTPATIENT DRUG FREE'
                  8='(8) ALCOHOL ONLY' 9='(9) COMBINED MODALITY' ;
  VALUE own       -9='(-9) UNKNOWN' -4='(-4) NOT MASTER FACILITY'
                  1='(1) PRIVATE FOR-PROFIT' 2='(2) PRIVATE NON-PROFIT'
                  3='(3) STATE OR LOCAL PUBLIC' 4='(4) FEDERAL PUBLIC'
                  5='(5) PUBLIC NON-PROFIT - PUBLIC FACILITY' ;
  VALUE env       -4='(-4) NOT MASTER FACILITY' 1='(1) HOSPITAL INPATIENT'
                  2='(2) RESIDENTIAL' 3='(3) OUTPATIENT' 8='(8) ALCOHOL ONLY'
                  9='(9) COMBINED MODALITY' ;
  VALUE xenv      -4='(-4) NOT MASTER FACILITY' 1='(1) HOSPITAL INPATIENT'
                  2='(2) RESIDENTIAL' 3='(3) OUTPATIENT DRUG DETOX'
                  4='(4) OUTPATIENT DRUG MAINTENANCE' 5='(5) OUTPATIENT DRUG FREE'
                  8='(8) ALCOHOL ONLY' 9='(9) COMBINED MODALITY' ;
  VALUE stratum   -4='(-4) NOT MASTER FACILITY'
                  1='(1) HOSPITAL IN-PATIENT DRUG TREATMENT'
                  2='(2) RESIDENTIAL DRUG TREATMENT'
                  3='(3) OUT-PATIENT DRUG DETOXIFICATION MAINTENANCE'
                  4='(4) OUT-PATIENT DRUG-FREE TREATMENT'
                  5='(5) ALCOHOL TREATMENT ONLY' 6='(6) UNKNOWN TREATMENT TYPE' ;
  VALUE region    -4='(-4) NOT MASTER FACILITY' 1='(1) NORTHEAST' 2='(2) NORTH CENTRAL'
                  3='(3) SOUTH' 4='(4) WEST' ;
  VALUE impflag   -4='(-4) NOT MASTER FACILITY'
                  0='(0) NO VARIABLES WERE IMPUTED FOR THIS FACILITY'
                  1='(1) AT LEAST ONE VARIABLE WAS IMPUTED' ;
  VALUE a7_box    -4='(-4) NOT MASTER FACILITY' 0='(0) BLANK, IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE a7a_ft    -8='(-8) DON''T KNOW' -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7a_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7a_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7a_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7b_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7b_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7b_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7b_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7c_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7c_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7c_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7c_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7d_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7d_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7d_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7d_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7e_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7e_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7e_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7e_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7f_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7f_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7f_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7f_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7g_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7g_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7g_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7g_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7h_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7h_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7h_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7h_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7i_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7i_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7i_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7i_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7j_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7j_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7j_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7j_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7k_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7k_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7k_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7k_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7l_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7l_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7l_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7l_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7m_ft    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7m_pt    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7m_con   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a7m_cert  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a8ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a9ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a10fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a11fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b1_box    -4='(-4) NOT MASTER FACILITY' 0='(0) BLANK - IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE hiddmcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hiddfcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hiddtcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hiddmact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hiddfact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hiddtact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidfmcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidffcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidftcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidfmact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidffact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidftact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsddmcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsddfcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsddtcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsddmact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsddfact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsddtact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdfmcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdffcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdftcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdfmact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdffact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdftact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE flag4_a   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_b   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_c   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_d   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_e   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_f   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_g   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_h   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_i   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_j   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_k   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_l   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_m   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_n   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_o   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag4_p   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE opddmcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opddfcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opddtcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opddmact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opddfact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opddtact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdmmcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdmfcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdmtcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdmmact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdmfact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdmtact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdfmcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdffcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdftcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdfmact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdffact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY GENDER'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdftact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OUT-PATIENT DRUG-FREE'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE flag5_a   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_b   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_c   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_d   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_e   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_f   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_g   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_h   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_i   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_j   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_k   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag5_l   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE alcmcap   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ALC TX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE alcfcap   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ALC TX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE alctcap   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ALC TX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE alcmact   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ALC TX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE alcfact   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ALC TX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE alctact   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -5='(-5) INAP - SRV UNIT DID NOT PROVIDE ALC TX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE totmcap   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE totfcap   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE totalcap  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE totmact   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE totfact   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - DATA NOT DIFFERENTIATED BY SEX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE totalact  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b2ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) ACTUAL NUMBERS FROM RECORDS'
                  2='(2) ESTIMATED NUMBERS FROM RECORDS' 3='(3) BEST GUESS'
                  4='(4) ACTUAL NUMBERS FROM AUTOMATED SYSTEM'
                  5='(5) ESTIMATED NUMBERS FROM AUTOMATED SYSTEM'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE b3ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE b4_no     -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO WAITING PERIOD' ;
  VALUE b4_unit   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) NO WAITING PERIOD' 1='(1) DAYS'
                  2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE b5ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE b6ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO WAIT-LIST' -4='(-4) NOT MASTER FACILITY' 1='(1) YES'
                  2='(2) NO' ;
  VALUE b7ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO WAIT-LIST' -4='(-4) NOT MASTER FACILITY' 1='(1) YES'
                  2='(2) NO' ;
  VALUE b8ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO WAIT-LIST' -4='(-4) NOT MASTER FACILITY' 1='(1) YES'
                  2='(2) NO' ;
  VALUE b9a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO WAIT-LIST' -4='(-4) NOT MASTER FACILITY' 1='(1) YES'
                  2='(2) NO' ;
  VALUE b9b       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO WAIT-LIST' -4='(-4) NOT MASTER FACILITY' 1='(1) YES'
                  2='(2) NO' ;
  VALUE waittime  -5.00='(-5.00) ROOT VARS MISSING - UNABLE TO CALCULATE'
                  -4.00='(-4.00) NOT MASTER FACILITY' ;
  VALUE flag6_a   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag6_b   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag6_c   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag6_d   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag6_e   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag6_f   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag6_g   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag6_h   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE b10_box   -4='(-4) NOT MASTER FACILITY'
                  0='(0) BLANK, BOX NOT CHECKED; IMPLICITLY ZERO' 1='(1) BOX CHECKED' ;
  VALUE hidd_a    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidd_b    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidd_c    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidd_d    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidd_e    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE INPX DETOX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_a    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_b    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_c    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_d    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_e    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_a    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_b    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_c    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_d    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_e    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_a    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_b    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_c    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_d    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_e    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_a    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_b    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_c    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_d    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_e    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_a    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_b    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_c    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_d    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_e    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_a    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_b    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_c    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_d    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_e    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -5='(-5) INAP - SRV UNIT DOES NOT PROVIDE OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE total_a   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE total_b   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE total_c   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE total_d   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE total_e   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - SRV UNIT DOES NOT HAVE A WAIT-LIST'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b11fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT HAVE WAIT-LIST'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) ACTUAL NUMBERS FROM RECORDS'
                  2='(2) ESTIMATED NUMBERS FROM RECORDS' 3='(3) BEST GUESS'
                  4='(4) ACTUAL NUMBERS FROM AUTOMATED SYSTEM'
                  5='(5) ESTIMATED NUMBERS FROM AUTOMATED SYSTEM'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE b12a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b12b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b12c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b12d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b12e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b12f      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b12g      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b12h      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b12i      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b12j      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) DO NOT TREAT'
                  2='(2) NO SPECIAL PRIORITY' 3='(3) SOME PRIORITY' ;
  VALUE b13a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b13b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b13c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b13d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b13e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b13f      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b13g      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b13h      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b13i      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b14fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) ACTUAL NUMBERS FROM RECORDS'
                  2='(2) ESTIMATED NUMBERS FROM RECORDS' 3='(3) BEST GUESS'
                  4='(4) ACTUAL NUMBERS FROM AUTOMATED SYSTEM'
                  5='(5) ESTIMATED NUMBERS FROM AUTOMATED SYSTEM'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE b15a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b15b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b15c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b15d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b15e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b16fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b17fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b18fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) ACTUAL NUMBERS FROM RECORDS'
                  2='(2) ESTIMATED NUMBERS FROM RECORDS' 3='(3) BEST GUESS'
                  4='(4) ACTUAL NUMBERS FROM AUTOMATED SYSTEM'
                  5='(5) ESTIMATED NUMBERS FROM AUTOMATED SYSTEM'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE flag9_a   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_b   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_c   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_d   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_e   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_f   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_g   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_h   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_i   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_j   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_k   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_l   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_m   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_n   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_o   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag9_p   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE b19fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b20a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b20b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b21fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b22fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b23fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b24a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b24b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b24c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b24d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b24e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b25fffff  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) BOX CHECKED, SKIP TO B26'
                  1='(1) BOX NOT CHECKED' ;
  VALUE b25a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO METH CLIENTS OR NO TAKE-HOME'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b25b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO METH CLIENTS OR NO TAKE-HOME'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b25c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO METH CLIENTS OR NO TAKE-HOME'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b25d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO METH CLIENTS OR NO TAKE-HOME'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b25e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO METH CLIENTS OR NO TAKE-HOME'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b25f      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO METH CLIENTS OR NO TAKE-HOME'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b25g      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO METH CLIENTS OR NO TAKE-HOME'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b25h      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NO METH CLIENTS OR NO TAKE-HOME'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b26_no    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b26_unit  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) WEEKS' 2='(2) MONTHS' 3='(3) YEARS' ;
  VALUE b27_no    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b27_unit  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' 0='(0) INDEFINATE, NO MAXIMUM'
                  1='(1) WEEKS' 2='(2) MONTHS' 3='(3) YEARS' ;
  VALUE b28a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - NO MAX LENGTH'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE b28b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - NO MAX LENGTH'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE b28c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - NO MAX LENGTH'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE b28d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - NO MAX LENGTH'
                  -5='(-5) INAP - SRV UNIT DID NOT HAVE MTHD CLIENTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE flag10_a  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_b  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_c  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_d  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_e  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_f  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_g  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_h  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_i  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_j  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_k  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag10_l  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE seq11fff  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidd_dem  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT CHECKED, IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE hidf_dem  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT CHECKED, IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE rsdd_dem  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT CHECKED, IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE rsdf_dem  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT CHECKED, IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE opdd_dem  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT CHECKED, IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE opdm_dem  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT CHECKED, IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE opdf_dem  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT CHECKED, IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE alc_dem   -4='(-4) NOT MASTER FACILITY' 0='(0) NOT CHECKED, IMPLICITLY ZERO'
                  1='(1) BOX CHECKED' ;
  VALUE a_white   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a_black   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a_hisp    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a_asian   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a_indian  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE a_other   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b_14ffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b_15ffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b_18ffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b_25ffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b_35ffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b_45ffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE b_65ffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE c_emp     -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE c_notemp  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED' ;
  VALUE demxenvf  -4='(-4) NOT MASTER FACILITY' 1='(1) HOSPITAL INPATIENT'
                  2='(2) RESIDENTIAL' 3='(3) OUTPATIENT DRUG DETOX'
                  4='(4) OUTPATIENT DRUG MAINTENANCE' 5='(5) OUTPATIENT DRUG FREE'
                  6='(6) OUTPATIENT COMBINED' 8='(8) ALCOHOL ONLY'
                  9='(9) COMBINED DRUG/ALCOHOL' 10='(10) COMBINED DRUG ONLY' ;
  VALUE seq12fff  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d_heroin  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d_crack   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d_cocain  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d_benz    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d_barb    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d_amph    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d_marij   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d_pcp     -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d_oth     -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE e_nopay   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE e_slfpay  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE e_privte  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE e_medcd   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE medcr_e   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE e_other   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE method    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) ACTUAL NUMBERS FROM RECORDS'
                  2='(2) ESTIMATED NUMBERS FROM RECORDS' 3='(3) BEST GUESS'
                  4='(4) ACTUAL NUMBERS FROM AUTOMATED SYSTEM'
                  5='(5) ESTIMATED NUMBERS FROM AUTOMATED SYSTEM'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE c1_box    -4='(-4) NOT MASTER FACILITY' 0='(0) BLANK, IMPLICTLY ZERO'
                  1='(1) CAN NOT EXCLUDE ALCOHOL ONLY CLIENTS' ;
  VALUE hidd_c1a  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidd_c1b  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidd_c1c  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidd_c1d  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidd_c1e  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_c1a  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_c1b  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_c1c  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_c1d  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_c1e  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_c1a  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_c1b  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_c1c  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_c1d  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_c1e  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_c1a  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_c1b  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_c1c  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_c1d  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_c1e  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE flag13_a  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_b  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_c  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_d  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_e  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_f  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_g  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_h  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_i  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_j  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_k  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_l  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_m  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_n  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_o  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_p  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_q  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_r  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_s  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag13_t  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE opdd_c1a  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_c1b  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_c1c  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_c1d  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_c1e  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_c1a  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_c1b  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_c1c  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_c1d  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_c1e  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_c1a  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_c1b  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_c1c  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_c1d  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_c1e  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DOES NOT OFFER OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE tot_c1a   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE tot_c1b   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE tot_c1c   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE tot_c1d   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE tot_c1e   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE c2ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) ACTUAL NUMBERS FROM RECORDS'
                  2='(2) ESTIMATED NUMBERS FROM RECORDS' 3='(3) BEST GUESS'
                  4='(4) ACTUAL NUMBERS FROM AUTOMATED SYSTEM'
                  5='(5) ESTIMATED NUMBERS FROM AUTOMATED SYSTEM'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE flag14_a  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_b  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_c  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_d  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_e  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_f  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_g  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_h  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_i  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_j  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_k  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_l  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_m  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_n  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_o  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_p  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_q  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_r  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_s  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag14_t  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE hiddpno   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO HIDD PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE hiddpunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO HIDD PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE hiddano   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO HIDD PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE hiddaunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO HIDD PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE hidfpno   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO HIDF PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidfpunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO HIDF PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE hidfano   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO HIDF PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidfaunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO HIDF PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE rsddpno   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO RSDD PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsddpunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO RSDD PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE rsddano   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO RSDD PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsddaunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO RSDD PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE rsdfpno   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO RSDF PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdfpunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO RSDF PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE rsdfano   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO RSDF PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdfaunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO RSDF PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE opddpno   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO OPDD PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE opddpunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO OPDD PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE opddano   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO OPDD PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE opddaunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO OPDD PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE opdmpno   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO OPDM PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdmpunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO OPDM PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE opdmano   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO OPDM PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdmaunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO OPDM PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE opdfpno   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO OPDF PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdfpunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO OPDF PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE opdfano   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - ZERO OPDF PATIENTS' -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdfaunt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - ZERO OPDF PATIENTS' -4='(-4) NOT MASTER FACILITY'
                  -1='(-1) BLANK IN SAS' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE c4ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) ACTUAL NUMBERS FROM RECORDS'
                  2='(2) ESTIMATED NUMBERS FROM RECORDS' 3='(3) BEST GUESS'
                  4='(4) ACTUAL NUMBERS FROM AUTOMATED SYSTEM'
                  5='(5) ESTIMATED NUMBERS FROM AUTOMATED SYSTEM'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE c5ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c6ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE c7a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c7b       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c7c       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c7d       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c7e       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c7f       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c7g       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c7h       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c7i       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c7j       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c8a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c8b       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c8c       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c8d       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c9ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c10_ref   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE c11_ref   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c12_tst   -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c13fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -6='(-6) INAP - NO PREGNANCY TESTS GIVEN'
                  -5='(-5) INAP - SRV UNIT DID NOT TX PREGNANT FEMALES'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE c14fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c16fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c17fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c18a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c18b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c18c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c19a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c19b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c19c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20a_adm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20a_trt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20a_dis  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20b_adm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20b_trt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20b_dis  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20c_adm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20c_trt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20c_dis  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20d_adm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20d_trt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20d_dis  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20e_adm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20e_trt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20e_dis  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20f_adm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20f_trt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20f_dis  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20g_adm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20g_trt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20g_dis  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20h_adm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20h_trt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20h_dis  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20i_adm  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20i_trt  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c20i_dis  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - SRV UNIT DID NOT CONDUCT TESTS'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c21fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c22_no    -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE c22_unit  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) PER DAY' 2='(2) PER WEEK'
                  3='(3) PER MONTH' 4='(4) PER YEAR' ;
  VALUE c23fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c24fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP-SRV UNIT DID NOT CONDUCT TESTS DURING TX'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c25fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE c26fffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW'
                  -5='(-5) INAP - BLANK OR C25 NOT CODED 1'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) PROGRAMS SPECIFIED' ;
  VALUE c27a      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27b      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27c      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27d      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27e      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27f      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27g      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27h      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27i      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27j      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27k      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE c27l      -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) YES, BY REFERRAL'
                  3='(3) NO' ;
  VALUE d1_box    -4='(-4) NOT MASTER FACILITY'
                  0='(0) BLANK, IMPLICITLY CAN EXCLUDE ALCOHOL CLIENTS'
                  1='(1) ALCOHOL ONLY CLIENTS COULD NOT BE EXCLUDED' ;
  VALUE hidd_d1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT OFFER HIDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE hidf_d1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT OFFER HIDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdd_d1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT OFFER RSDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE rsdf_d1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT OFFER RSDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdd_d1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT OFFER OPDD'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdm_d1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT OFFER OPDM'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE opdf_d1f  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - SRV UNIT DID NOT OFFER OPDF'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE total_df  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d2ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) ACTUAL NUMBERS FROM RECORDS'
                  2='(2) ESTIMATED NUMBERS FROM RECORDS' 3='(3) BEST GUESS'
                  4='(4) ACTUAL NUMBERS FROM AUTOMATED SYSTEM'
                  5='(5) ESTIMATED NUMBERS FROM AUTOMATED SYSTEM'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE flag17_a  -4='(-4) NOT MASTER FACILITY' 0='(0) VARIABLE WAS NOT IMPUTED'
                  1='(1) VARIABLE WAS IMPUTED USING THE HOT DECK METHOD WITH'
                  2='(2) VARIABLE WAS MANUALLY ASSIGNED BASED ON OTHER'
                  3='(3) VARIABLE WAS IMPUTED USING A STRAIGHT HOT DECK METHOD'
                  4='(4) VARIABLE WAS IMPUTED FROM NDATUS EITHER USING A FACTOR'
                  5='(5) VARIABLE WAS ASSIGNED AS THE DIFFERENCE BETWEEN A TOTAL AND'
                  6='(6) A TOTAL OR SUBTOTAL WAS RECALCULATED BECAUSE THE SUM OF'
                  7='(7) A TOTAL WAS ASSIGNED THE SUMMING OF ALL THE PARTS, IF THEY'
                  8='(8) VARIABLE WAS IMPUTED FROM B1 TOTAL ACTUAL BASED ON THE'
                  9='(9) VARIABLE WAS IMPUTED FROM C1 COLUMN A TOTAL BASED ON' ;
  VALUE d3ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' 1='(1) YES' 2='(2) NO' ;
  VALUE d4ffffff  -7='(-7) REFUSED' -5='(-5) INAP - NOT CERTIFIED BY MEDICAID'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d5ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -5='(-5) INAP - NOT CERTIFIED BY MEDICAID'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d6ffffff  -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7a       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7b       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7c       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7d       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7e       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7f       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7g       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7h       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7i       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7j       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7k       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE d7l       -9='(-9) NOT ASCERTAINED' -8='(-8) DON''T KNOW' -7='(-7) REFUSED'
                  -4='(-4) NOT MASTER FACILITY' ;
  VALUE keybatch  -4='(-4) NOT MASTER FACILITY' ;
  VALUE flag18_a  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_b  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_c  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_d  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_e  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_f  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_g  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_h  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_i  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_j  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_k  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_l  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE flag18_m  -4='(-4) NOT MASTER FACILITY' 0='(0) NOT IMPUTED'
                  1='(1) HOT DECK - PROPORTIONAL ASSIGNMENT'
                  2='(2) MANUAL RECALCULATION BASED ON VARS IN SAME REC'
                  3='(3) HOT DECK - TRADITIONAL SUBSTITUTION'
                  4='(4) IMPUTED FROM NDATUS'
                  5='(5) IMPUTED BASED ON OTHER VARS IN SAME REC'
                  6='(6) TOTAL/SUBTOTAL WAS RECALC B/C OF IMPUTATION'
                  7='(7) TOTAL WAS DERVIED FROM NON-MISSING SUB-PARTS'
                  8='(8) B1 RATIO IMPUTATION BASED ON DONOR PATTERN'
                  9='(9) C1 RATIO IMPUTATION BASED ON DONOR PATTERN' ;
  VALUE nfinwt0f  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt1fff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt2fff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt3fff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt4fff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt5fff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt6fff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt7fff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt8fff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt9fff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt10ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt11ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt12ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt13ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt14ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt15ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt16ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt17ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt18ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt19ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt20ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt21ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt22ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt23ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt24ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt25ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt26ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt27ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt28ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt29ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
  VALUE rpwt30ff  -4.000000='(-4.000000) NOT MASTER FACILITY' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=1820;
INPUT
        CASEID 1-8              OBS_NUM 9-12            CRP_MO1 13-14
        CRP_DA1 15-16           CRP_YR1 17-18           CRP_MO2 19-20
        CRP_DA2 21-22           CRP_YR2 23-24           CLENGTH 25-26
        FRP_MO1 27-28           FRP_DA1 29-30           FRP_YR1 31-32
        FRP_MO2 33-34           FRP_DA2 35-36           FRP_YR2 37-38
        FLENGTH 39-40           A1_NO 41-43             A1_UNIT 44-45
        A2A 46-47               A2B 48-49               A2C 50-51
        A2D 52-53               A2E 54-55               A3A 56-57
        A3B 58-59               A3C 60-61               A3D 62-63
        A3E 64-65               A4A 66-67               A4B 68-69
        A4C 70-71               A4D 72-73               A4E 74-75
        A4F 76-77               A5A 78-79               A5B 80-81
        HIDD_A6 82-83           HIDM_A6 84-85           HIDF_A6 86-87
        RSDD_A6 88-89           RSDM_A6 90-91           RSDF_A6 92-93
        OPDD_A6 94-95           OPDM_A6 96-97           OPDF_A6 98-99
        ALC_A6 100-101          CORRFAC 102-103         ALCHONLY 104-105
        SEQ11CNT 106-107        SEQ12CNT 108-109        NUMMOD 110-111
        MOD 112-113             OWN 114-115             ENV 116-117
        XENV 118-119            STRATUM 120-121         REGION 122-123
        IMPFLAG 124-125         A7_BOX 126-127          A7A_FT 128-129
        A7A_PT 130-131          A7A_CON 132-133         A7A_CERT 134-135
        A7B_FT 136-137          A7B_PT 138-139          A7B_CON 140-141
        A7B_CERT 142-143        A7C_FT 144-146          A7C_PT 147-148
        A7C_CON 149-150         A7C_CERT 151-152        A7D_FT 153-154
        A7D_PT 155-156          A7D_CON 157-158         A7D_CERT 159-160
        A7E_FT 161-162          A7E_PT 163-164          A7E_CON 165-166
        A7E_CERT 167-168        A7F_FT 169-170          A7F_PT 171-172
        A7F_CON 173-174         A7F_CERT 175-176        A7G_FT 177-178
        A7G_PT 179-180          A7G_CON 181-182         A7G_CERT 183-184
        A7H_FT 185-186          A7H_PT 187-188          A7H_CON 189-190
        A7H_CERT 191-192        A7I_FT 193-194          A7I_PT 195-196
        A7I_CON 197-198         A7I_CERT 199-200        A7J_FT 201-202
        A7J_PT 203-204          A7J_CON 205-206         A7J_CERT 207-208
        A7K_FT 209-210          A7K_PT 211-212          A7K_CON 213-215
        A7K_CERT 216-217        A7L_FT 218-219          A7L_PT 220-221
        A7L_CON 222-223         A7L_CERT 224-225        A7M_FT 226-228
        A7M_PT 229-230          A7M_CON 231-232         A7M_CERT 233-234
        A8 235-237              A9 238-240              A10 241-243
        A11 244-245             B1_BOX 246-247          HIDDMCAP 248-249
        HIDDFCAP 250-251        HIDDTCAP 252-254        HIDDMACT 255-256
        HIDDFACT 257-258        HIDDTACT 259-260        HIDFMCAP 261-262
        HIDFFCAP 263-264        HIDFTCAP 265-267        HIDFMACT 268-270
        HIDFFACT 271-272        HIDFTACT 273-275        RSDDMCAP 276-277
        RSDDFCAP 278-279        RSDDTCAP 280-282        RSDDMACT 283-284
        RSDDFACT 285-286        RSDDTACT 287-288        RSDFMCAP 289-291
        RSDFFCAP 292-293        RSDFTCAP 294-296        RSDFMACT 297-299
        RSDFFACT 300-301        RSDFTACT 302-304        FLAG4_A 305-306
        FLAG4_B 307-308         FLAG4_C 309-310         FLAG4_D 311-312
        FLAG4_E 313-314         FLAG4_F 315-316         FLAG4_G 317-318
        FLAG4_H 319-320         FLAG4_I 321-322         FLAG4_J 323-324
        FLAG4_K 325-326         FLAG4_L 327-328         FLAG4_M 329-330
        FLAG4_N 331-332         FLAG4_O 333-334         FLAG4_P 335-336
        OPDDMCAP 337-338        OPDDFCAP 339-340        OPDDTCAP 341-344
        OPDDMACT 345-347        OPDDFACT 348-349        OPDDTACT 350-352
        OPDMMCAP 353-355        OPDMFCAP 356-358        OPDMTCAP 359-362
        OPDMMACT 363-366        OPDMFACT 367-370        OPDMTACT 371-374
        OPDFMCAP 375-377        OPDFFCAP 378-380        OPDFTCAP 381-384
        OPDFMACT 385-387        OPDFFACT 388-391        OPDFTACT 392-395
        FLAG5_A 396-397         FLAG5_B 398-399         FLAG5_C 400-401
        FLAG5_D 402-403         FLAG5_E 404-405         FLAG5_F 406-407
        FLAG5_G 408-409         FLAG5_H 410-411         FLAG5_I 412-413
        FLAG5_J 414-415         FLAG5_K 416-417         FLAG5_L 418-419
        ALCMCAP 420-422         ALCFCAP 423-425         ALCTCAP 426-429
        ALCMACT 430-432         ALCFACT 433-435         ALCTACT 436-438
        TOTMCAP 439-442         TOTFCAP 443-445         TOTALCAP 446-449
        TOTMACT 450-454         TOTFACT 455-458         TOTALACT 459-463
        B2 464-465              B3 466-467              B4_NO 468-470
        B4_UNIT 471-472         B5 473-474              B6 475-476
        B7 477-478              B8 479-480              B9A 481-482
        B9B 483-484             WAITTIME 485-490 .2     FLAG6_A 491-492
        FLAG6_B 493-494         FLAG6_C 495-496         FLAG6_D 497-498
        FLAG6_E 499-500         FLAG6_F 501-502         FLAG6_G 503-504
        FLAG6_H 505-506         B10_BOX 507-508         HIDD_A 509-511
        HIDD_B 512-513          HIDD_C 514-515          HIDD_D 516-517
        HIDD_E 518-519          HIDF_A 520-522          HIDF_B 523-524
        HIDF_C 525-527          HIDF_D 528-529          HIDF_E 530-531
        RSDD_A 532-533          RSDD_B 534-535          RSDD_C 536-537
        RSDD_D 538-539          RSDD_E 540-541          RSDF_A 542-544
        RSDF_B 545-546          RSDF_C 547-549          RSDF_D 550-552
        RSDF_E 553-554          OPDD_A 555-556          OPDD_B 557-558
        OPDD_C 559-560          OPDD_D 561-562          OPDD_E 563-564
        OPDM_A 565-567          OPDM_B 568-570          OPDM_C 571-572
        OPDM_D 573-574          OPDM_E 575-577          OPDF_A 578-580
        OPDF_B 581-582          OPDF_C 583-585          OPDF_D 586-588
        OPDF_E 589-591          TOTAL_A 592-595         TOTAL_B 596-597
        TOTAL_C 598-601         TOTAL_D 602-604         TOTAL_E 605-607
        B11 608-609             B12A 610-611            B12B 612-613
        B12C 614-615            B12D 616-617            B12E 618-619
        B12F 620-621            B12G 622-623            B12H 624-625
        B12I 626-627            B12J 628-629            B13A 630-632
        B13B 633-635            B13C 636-638            B13D 639-640
        B13E 641-643            B13F 644-646            B13G 647-648
        B13H 649-650            B13I 651-653            B14 654-655
        B15A 656-658            B15B 659-661            B15C 662-664
        B15D 665-667            B15E 668-670            B16 671-673
        B17 674-676             B18 677-678             FLAG9_A 679-680
        FLAG9_B 681-682         FLAG9_C 683-684         FLAG9_D 685-686
        FLAG9_E 687-688         FLAG9_F 689-690         FLAG9_G 691-692
        FLAG9_H 693-694         FLAG9_I 695-696         FLAG9_J 697-698
        FLAG9_K 699-700         FLAG9_L 701-702         FLAG9_M 703-704
        FLAG9_N 705-706         FLAG9_O 707-708         FLAG9_P 709-710
        B19 711-714             B20A 715-717            B20B 718-721
        B21 722-724             B22 725-726             B23 727-728
        B24A 729-731            B24B 732-734            B24C 735-738
        B24D 739-742            B24E 743-746            B25 747-748
        B25A 749-751            B25B 752-754            B25C 755-758
        B25D 759-761            B25E 762-765            B25F 766-769
        B25G 770-771            B25H 772-773            B26_NO 774-775
        B26_UNIT 776-777        B27_NO 778-779          B27_UNIT 780-781
        B28A 782-783            B28B 784-785            B28C 786-787
        B28D 788-789            FLAG10_A 790-791        FLAG10_B 792-793
        FLAG10_C 794-795        FLAG10_D 796-797        FLAG10_E 798-799
        FLAG10_F 800-801        FLAG10_G 802-803        FLAG10_H 804-805
        FLAG10_I 806-807        FLAG10_J 808-809        FLAG10_K 810-811
        FLAG10_L 812-813        SEQ11 814               HIDD_DEM 815
        HIDF_DEM 816            RSDD_DEM 817            RSDF_DEM 818
        OPDD_DEM 819            OPDM_DEM 820            OPDF_DEM 821
        ALC_DEM 822             A_WHITE 823-826         A_BLACK 827-830
        A_HISP 831-834          A_ASIAN 835-836         A_INDIAN 837-838
        A_OTHER 839-840         B_14 841-843            B_15 844-846
        B_18 847-849            B_25 850-853            B_35 854-857
        B_45 858-861            B_65 862-863            C_EMP 864-867
        C_NOTEMP 868-872        DEMXENV2 873-874        SEQ12 875
        D_HEROIN 876-879        D_CRACK 880-883         D_COCAIN 884-886
        D_BENZ 887-889          D_BARB 890-891          D_AMPH 892-894
        D_MARIJ 895-897         D_PCP 898-899           D_OTH 900-902
        E_NOPAY 903-906         E_SLFPAY 907-910        E_PRIVTE 911-914
        E_MEDCD 915-918         MEDCR_E 919-921         E_OTHER 922-926
        METHOD 927-928          C1_BOX 929-930          HIDD_C1A 931-934
        HIDD_C1B 935-938        HIDD_C1C 939-942        HIDD_C1D 943-945
        HIDD_C1E 946-948        HIDF_C1A 949-952        HIDF_C1B 953-956
        HIDF_C1C 957-960        HIDF_C1D 961-963        HIDF_C1E 964-966
        RSDD_C1A 967-971        RSDD_C1B 972-976        RSDD_C1C 977-980
        RSDD_C1D 981-984        RSDD_C1E 985-987        RSDF_C1A 988-991
        RSDF_C1B 992-995        RSDF_C1C 996-999        RSDF_C1D 1000-1002
        RSDF_C1E 1003-1005      FLAG13_A 1006-1007      FLAG13_B 1008-1009
        FLAG13_C 1010-1011      FLAG13_D 1012-1013      FLAG13_E 1014-1015
        FLAG13_F 1016-1017      FLAG13_G 1018-1019      FLAG13_H 1020-1021
        FLAG13_I 1022-1023      FLAG13_J 1024-1025      FLAG13_K 1026-1027
        FLAG13_L 1028-1029      FLAG13_M 1030-1031      FLAG13_N 1032-1033
        FLAG13_O 1034-1035      FLAG13_P 1036-1037      FLAG13_Q 1038-1039
        FLAG13_R 1040-1041      FLAG13_S 1042-1043      FLAG13_T 1044-1045
        OPDD_C1A 1046-1049      OPDD_C1B 1050-1053      OPDD_C1C 1054-1056
        OPDD_C1D 1057-1060      OPDD_C1E 1061-1063      OPDM_C1A 1064-1067
        OPDM_C1B 1068-1071      OPDM_C1C 1072-1074      OPDM_C1D 1075-1078
        OPDM_C1E 1079-1082      OPDF_C1A 1083-1087      OPDF_C1B 1088-1092
        OPDF_C1C 1093-1097      OPDF_C1D 1098-1101      OPDF_C1E 1102-1105
        TOT_C1A 1106-1110       TOT_C1B 1111-1115       TOT_C1C 1116-1120
        TOT_C1D 1121-1124       TOT_C1E 1125-1128       C2 1129-1130
        FLAG14_A 1131-1132      FLAG14_B 1133-1134      FLAG14_C 1135-1136
        FLAG14_D 1137-1138      FLAG14_E 1139-1140      FLAG14_F 1141-1142
        FLAG14_G 1143-1144      FLAG14_H 1145-1146      FLAG14_I 1147-1148
        FLAG14_J 1149-1150      FLAG14_K 1151-1152      FLAG14_L 1153-1154
        FLAG14_M 1155-1156      FLAG14_N 1157-1158      FLAG14_O 1159-1160
        FLAG14_P 1161-1162      FLAG14_Q 1163-1164      FLAG14_R 1165-1166
        FLAG14_S 1167-1168      FLAG14_T 1169-1170      HIDDPNO 1171-1172
        HIDDPUNT 1173-1174      HIDDANO 1175-1176       HIDDAUNT 1177-1178
        HIDFPNO 1179-1180       HIDFPUNT 1181-1182      HIDFANO 1183-1185
        HIDFAUNT 1186-1187      RSDDPNO 1188-1189       RSDDPUNT 1190-1191
        RSDDANO 1192-1193       RSDDAUNT 1194-1195      RSDFPNO 1196-1198
        RSDFPUNT 1199-1200      RSDFANO 1201-1203       RSDFAUNT 1204-1205
        OPDDPNO 1206-1208       OPDDPUNT 1209-1210      OPDDANO 1211-1213
        OPDDAUNT 1214-1215      OPDMPNO 1216-1218       OPDMPUNT 1219-1220
        OPDMANO 1221-1223       OPDMAUNT 1224-1225      OPDFPNO 1226-1228
        OPDFPUNT 1229-1230      OPDFANO 1231-1233       OPDFAUNT 1234-1235
        C4 1236-1237            C5 1238-1239            C6 1240-1242
        C7A 1243-1244           C7B 1245-1246           C7C 1247-1248
        C7D 1249-1250           C7E 1251-1252           C7F 1253-1254
        C7G 1255-1256           C7H 1257-1258           C7I 1259-1260
        C7J 1261-1262           C8A 1263-1264           C8B 1265-1266
        C8C 1267-1268           C8D 1269-1270           C9 1271-1272
        C10_REF 1273-1275       C11_REF 1276-1277       C12_TST 1278-1279
        C13 1280-1281           C14 1282-1283           C16 1284-1285
        C17 1286-1287           C18A 1288-1289          C18B 1290-1291
        C18C 1292-1293          C19A 1294-1295          C19B 1296-1297
        C19C 1298-1299          C20A_ADM 1300-1301      C20A_TRT 1302-1303
        C20A_DIS 1304-1305      C20B_ADM 1306-1307      C20B_TRT 1308-1309
        C20B_DIS 1310-1311      C20C_ADM 1312-1313      C20C_TRT 1314-1315
        C20C_DIS 1316-1317      C20D_ADM 1318-1319      C20D_TRT 1320-1321
        C20D_DIS 1322-1323      C20E_ADM 1324-1325      C20E_TRT 1326-1327
        C20E_DIS 1328-1329      C20F_ADM 1330-1331      C20F_TRT 1332-1333
        C20F_DIS 1334-1335      C20G_ADM 1336-1337      C20G_TRT 1338-1339
        C20G_DIS 1340-1341      C20H_ADM 1342-1343      C20H_TRT 1344-1345
        C20H_DIS 1346-1347      C20I_ADM 1348-1349      C20I_TRT 1350-1351
        C20I_DIS 1352-1353      C21 1354-1355           C22_NO 1356-1357
        C22_UNIT 1358-1359      C23 1360-1361           C24 1362-1363
        C25 1364-1365           C26 1366-1367           C27A 1368-1369
        C27B 1370-1371          C27C 1372-1373          C27D 1374-1375
        C27E 1376-1377          C27F 1378-1379          C27G 1380-1381
        C27H 1382-1383          C27I 1384-1385          C27J 1386-1387
        C27K 1388-1389          C27L 1390-1391          D1_BOX 1392-1393
        HIDD_D1 1394-1400       HIDF_D1 1401-1408       RSDD_D1 1409-1415
        RSDF_D1 1416-1422       OPDD_D1 1423-1428       OPDM_D1 1429-1436
        OPDF_D1 1437-1443       TOTAL_D1 1444-1452      D2 1453-1454
        FLAG17_A 1455-1456      D3 1457-1458            D4 1459-1466
        D5 1467-1470            D6 1471-1479            D7A 1480-1482
        D7B 1483-1485           D7C 1486-1488           D7D 1489-1491
        D7E 1492-1494           D7F 1495-1497           D7G 1498-1500
        D7H 1501-1503           D7I 1504-1505           D7J 1506-1507
        D7K 1508-1510           D7L 1511-1513           KEYBATCH 1514-1515
        FLAG18_A 1516-1517      FLAG18_B 1518-1519      FLAG18_C 1520-1521
        FLAG18_D 1522-1523      FLAG18_E 1524-1525      FLAG18_F 1526-1527
        FLAG18_G 1528-1529      FLAG18_H 1530-1531      FLAG18_I 1532-1533
        FLAG18_J 1534-1535      FLAG18_K 1536-1537      FLAG18_L 1538-1539
        FLAG18_M 1540-1541      NFINWT0 1542-1550 .6    RPWT1 1551-1559 .6
        RPWT2 1560-1568 .6      RPWT3 1569-1577 .6      RPWT4 1578-1586 .6
        RPWT5 1587-1595 .6      RPWT6 1596-1604 .6      RPWT7 1605-1613 .6
        RPWT8 1614-1622 .6      RPWT9 1623-1631 .6      RPWT10 1632-1640 .6
        RPWT11 1641-1649 .6     RPWT12 1650-1658 .6     RPWT13 1659-1667 .6
        RPWT14 1668-1676 .6     RPWT15 1677-1685 .6     RPWT16 1686-1694 .6
        RPWT17 1695-1703 .6     RPWT18 1704-1712 .6     RPWT19 1713-1721 .6
        RPWT20 1722-1730 .6     RPWT21 1731-1739 .6     RPWT22 1740-1748 .6
        RPWT23 1749-1757 .6     RPWT24 1758-1766 .6     RPWT25 1767-1775 .6
        RPWT26 1776-1784 .6     RPWT27 1785-1793 .6     RPWT28 1794-1802 .6
        RPWT29 1803-1811 .6     RPWT30 1812-1820 .6     ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   OBS_NUM = 'FACILITY OBSERVATION NUMBER'
   CRP_MO1 = 'CLIENT REPORT PERIOD - FROM MONTH'
   CRP_DA1 = 'CLIENT REPORT PERIOD - FROM DAY'
   CRP_YR1 = 'CLIENT REPORT PERIOD - FROM YEAR'
   CRP_MO2 = 'CLIENT REPORT PERIOD - TO MONTH'
   CRP_DA2 = 'CLIENT REPORT PERIOD - TO DAY'
   CRP_YR2 = 'CLIENT REPORT PERIOD - TO YEAR'
   CLENGTH = 'CLIENT REPORT PERIOD - LENGTH (IN MONTHS)'
   FRP_MO1 = 'FINANCIAL REPORT PERIOD - FROM MONTH'
   FRP_DA1 = 'FINANCIAL REPORT PERIOD - FROM DAY'
   FRP_YR1 = 'FINANCIAL REPORT PERIOD - FROM YEAR'
   FRP_MO2 = 'FINANCIAL REPORT PERIOD - TO MONTH'
   FRP_DA2 = 'FINANCIAL REPORT PERIOD - TO DAY'
   FRP_YR2 = 'FINANCIAL REPORT PERIOD - TO YEAR'
   FLENGTH = 'FINANCIAL REPORT PERIOD - LENGTH (IN MONTHS)'
   A1_NO   = 'A1. DRUG TREATMENT OFFERED-NUMBER'
   A1_UNIT = 'A1. DRUG TREATMENT OFFERED-UNIT'
   A2A     = 'A2A. OWNED - PRIVATE FOR-PROFIT'
   A2B     = 'A2B. OWNED - PRIVATE NOT-FOR-PROFIT'
   A2C     = 'A2C. OWNED - PUBLIC CITY/COUNTY'
   A2D     = 'A2D. OWNED - PUBLIC STATE'
   A2E     = 'A2E. OWNED - PUBLIC FEDERAL'
   A3A     = 'A3A. MANAGED - PRIVATE FOR-PROFIT'
   A3B     = 'A3B. MANAGED - PRIVATE NOT-FOR-PROFIT'
   A3C     = 'A3C. MANAGED - PUBLIC CITY/COUNTY'
   A3D     = 'A3D. MANAGED - PUBLIC STATE'
   A3E     = 'A3E. MANAGED - PUBLIC FEDERAL'
   A4A     = 'A4A. LICENSING - STATE'
   A4B     = 'A4B. LICENSING - COUNTY'
   A4C     = 'A4C. LICENSING - CITY'
   A4D     = 'A4D. LICENSING - FDA'
   A4E     = 'A4E. LICENSING - DEA'
   A4F     = 'A4F. LICENSING - OTHER'
   A5A     = 'A5A. ACCREDITATION - HEALTH CARE'
   A5B     = 'A5B. ACCREDITATION - OTHER'
   HIDD_A6 = 'A6A1. HOSP INPT - DRUG DETOX'
   HIDM_A6 = 'A6A2. HOSP INPT - DRUG MAINTENANCE'
   HIDF_A6 = 'A6A3. HOSP INPT - DRUG FREE'
   RSDD_A6 = 'A6B1. RESIDENTIAL - DRUG DETOX'
   RSDM_A6 = 'A6B2. RESIDENTIAL - DRUG MAINTENANCE'
   RSDF_A6 = 'A6B3. RESIDENTIAL - DRUG FREE'
   OPDD_A6 = 'A6C1. OUTPATIENT - DRUG DETOX'
   OPDM_A6 = 'A6C2. OUTPATIENT - DRUG MAINTENANCE'
   OPDF_A6 = 'A6C3. OUTPATIENT - DRUG FREE'
   ALC_A6  = 'A6D1. ALCOHOL TREATMENT'
   CORRFAC = 'CORRECTIONAL FACILITIES'
   ALCHONLY= 'ALCOHOL ONLY FACILITIES'
   SEQ11CNT= 'NUMBER OF RECORD 11S A FACILITY HAS'
   SEQ12CNT= 'NUMBER OF RECORD 12S A FACILITY HAS'
   NUMMOD  = 'NUMBER OF YES RESPONSES TO A6 VARIABLES'
   MOD     = 'MODALITY OF TREATMENT'
   OWN     = 'OWNERSHIP STATUS'
   ENV     = 'ENVIRONMENT OF TREATMENT'
   XENV    = 'EXPANDED ENVIRONMENT'
   STRATUM = 'STRATUM - SAMPLING FRAME'
   REGION  = 'REGION - CENSUS REGION'
   IMPFLAG = 'IMPUTATION FLAG 0/1 = NO/YES'
   A7_BOX  = 'A7. ALCOHOL ONLY BOX CHECKED'
   A7A_FT  = 'A7A. PSYCHIATRISTS - FULL-TIME'
   A7A_PT  = 'A7A. PSYCHIATRISTS - PART-TIME'
   A7A_CON = 'A7A. PSYCHIATRISTS - CONTRACT'
   A7A_CERT= 'A7A. PSYCHIATRISTS - CERTIFIED'
   A7B_FT  = 'A7B. OTHER PHYSICIANS - FULL-TIME'
   A7B_PT  = 'A7B. OTHER PHYSICIANS - PART-TIME'
   A7B_CON = 'A7B. OTHER PHYSICIANS - CONTRACT'
   A7B_CERT= 'A7B. OTHER PHYSICIANS - CERTIFIED'
   A7C_FT  = 'A7C. RN''S - FULL-TIME'
   A7C_PT  = 'A7C. RN''S - PART-TIME'
   A7C_CON = 'A7C. RN''S - CONTRACT'
   A7C_CERT= 'A7C. RN''S - CERTIFIED'
   A7D_FT  = 'A7D. LPN''S/LVN''S - FULL-TIME'
   A7D_PT  = 'A7D. LPN''S/LVN''S - PART-TIME'
   A7D_CON = 'A7D. LPN''S/LVN''S - CONTRACT'
   A7D_CERT= 'A7D. LPN''S/LVN''S - CERTIFIED'
   A7E_FT  = 'A7E. OTHER MEDICAL - FULL-TIME'
   A7E_PT  = 'A7E. OTHER MEDICAL - PART-TIME'
   A7E_CON = 'A7E. OTHER MEDICAL - CONTRACT'
   A7E_CERT= 'A7E. OTHER MEDICAL - CERTIFIED'
   A7F_FT  = 'A7F. PSYCHOLOGISTS - FULL-TIME'
   A7F_PT  = 'A7F. PSYCHOLOGISTS - PART-TIME'
   A7F_CON = 'A7F. PSYCHOLOGISTS - CONTRACT'
   A7F_CERT= 'A7F. PSYCHOLOGISTS - CERTIFIED'
   A7G_FT  = 'A7G. SOCIAL WORKERS - FULL-TIME'
   A7G_PT  = 'A7G. SOCIAL WORKERS - PART-TIME'
   A7G_CON = 'A7G. SOCIAL WORKERS - CONTRACT'
   A7G_CERT= 'A7G. SOCIAL WORKERS - CERTIFIED'
   A7H_FT  = 'A7H. FAMILY THERAPISTS - FULL-TIME'
   A7H_PT  = 'A7H. FAMILY THERAPISTS - PART-TIME'
   A7H_CON = 'A7H. FAMILY THERAPISTS - CONTRACT'
   A7H_CERT= 'A7H. FAMILY THERAPISTS - CERTIFIED'
   A7I_FT  = 'A7I. VOCATIONAL REHAB SPEC - FULL-TIME'
   A7I_PT  = 'A7I. VOCATIONAL REHAB SPEC - PART-TIME'
   A7I_CON = 'A7I. VOCATIONAL REHAB SPEC - CONTRACT'
   A7I_CERT= 'A7I. VOCATIONAL REHAB SPEC - CERTIFIED'
   A7J_FT  = 'A7J. DEGREED COUNSELORS - FULL-TIME'
   A7J_PT  = 'A7J. DEGREED COUNSELORS - PART-TIME'
   A7J_CON = 'A7J. DEGREED COUNSELORS - CONTRACT'
   A7J_CERT= 'A7J. DEGREED COUNSELORS - CERTIFIED'
   A7K_FT  = 'A7K. NON-DEGREED COUNSELORS - FULL-TIME'
   A7K_PT  = 'A7K. NON-DEGREED COUNSELORS - PART-TIME'
   A7K_CON = 'A7K. NON-DEGREED COUNSELORS - CONTRACT'
   A7K_CERT= 'A7K. NON-DEGREED COUNSELORS - CERTIFIED'
   A7L_FT  = 'A7L. SUPPORT STAFF - FULL-TIME'
   A7L_PT  = 'A7L. SUPPORT STAFF - PART-TIME'
   A7L_CON = 'A7L. SUPPORT STAFF - CONTRACT'
   A7L_CERT= 'A7L. SUPPORT STAFF - CERTIFIED'
   A7M_FT  = 'A7M. OTHER STAFF - FULL-TIME'
   A7M_PT  = 'A7M. OTHER STAFF - PART-TIME'
   A7M_CON = 'A7M. OTHER STAFF - CONTRACT'
   A7M_CERT= 'A7M. OTHER STAFF - CERTIFIED'
   A8      = 'A8. ACTIVE VOLUNTEERS'
   A9      = 'A9. CLIENT % FROM CITY/TOWN'
   A10     = 'A10. CLIENT % FROM OUTSIDE CITY'
   A11     = 'A11. CLIENT % FROM OUTSIDE STATE'
   B1_BOX  = 'B1. DATA NOT DIFFERENTIATED BY GENDER'
   HIDDMCAP= 'B1A. HSP INPT DRG DETOX CAPACITY-MALE'
   HIDDFCAP= 'B1B. HSP INPT DRG DETOX CAPACITY-FEMALE'
   HIDDTCAP= 'B1C. HSP INPT DRG DETOX CAPACITY-TOTAL'
   HIDDMACT= 'B1D. HSP INPT DRG DETOX ACTUAL-MALE'
   HIDDFACT= 'B1E. HSP INPT DRG DETOX ACTUAL-FEMALE'
   HIDDTACT= 'B1F. HSP INPT DRG DETOX ACTUAL-TOTAL'
   HIDFMCAP= 'B1A. HSP INPT DRG FREE CAPACITY-MALE'
   HIDFFCAP= 'B1B. HSP INPT DRG FREE CAPACITY-FEMALE'
   HIDFTCAP= 'B1C. HSP INPT DRG FREE CAPACITY-TOTAL'
   HIDFMACT= 'B1D. HSP INPT DRG FREE ACTUAL-MALE'
   HIDFFACT= 'B1E. HSP INPT DRG FREE ACTUAL-FEMALE'
   HIDFTACT= 'B1F. HSP INPT DRG FREE ACTUAL-TOTAL'
   RSDDMCAP= 'B1A. RESIDNTL DRG DETOX CAPACITY-MALE'
   RSDDFCAP= 'B1B. RESIDNTL DRG DETOX CAPACITY-FEMALE'
   RSDDTCAP= 'B1C. RESIDNTL DRG DETOX CAPACITY-TOTAL'
   RSDDMACT= 'B1D. RESIDNTL DRG DETOX ACTUAL-MALE'
   RSDDFACT= 'B1E. RESIDNTL DRG DETOX ACTUAL-FEMALE'
   RSDDTACT= 'B1F. RESIDNTL DRG DETOX ACTUAL-TOTAL'
   RSDFMCAP= 'B1A. RESIDNTL DRG FREE CAPACITY-MALE'
   RSDFFCAP= 'B1B. RESIDNTL DRG FREE CAPACITY-FEMALE'
   RSDFTCAP= 'B1C. RESIDNTL DRG FREE CAPACITY-TOTAL'
   RSDFMACT= 'B1D. RESIDNTL DRG FREE ACTUAL-MALE'
   RSDFFACT= 'B1E. RESIDNTL DRG FREE ACTUAL-FEMALE'
   RSDFTACT= 'B1F. RESIDNTL DRG FREE ACTUAL-TOTAL'
   FLAG4_A = 'HOSP INP DRUG DETOX TOTAL CAPACITY IMPUTATION FLAG'
   FLAG4_B = 'HOSP INP DRUG DETOX ACTUAL # MEN IMPUTATION FLAG'
   FLAG4_C = 'HOSP INP DRUG DETOX ACTUAL # WOMEN IMPUTATION FLAG'
   FLAG4_D = 'HOSP INP DRUG DETOX ACTUAL # TOTAL IMPUTATION FLAG'
   FLAG4_E = 'HOSP INP DRUG-FREE TOTAL CAPACITY IMPUTATION FLAG'
   FLAG4_F = 'HOSP INP DRUG-FREE ACTUAL # MEN IMPUTATION FLAG'
   FLAG4_G = 'HOSP INP DRUG-FREE ACTUAL # WOMEN IMPUTATION FLAG'
   FLAG4_H = 'HOSP INP DRUG-FREE ACTUAL # TOTAL IMPUTATION FLAG'
   FLAG4_I = 'RES DRUG DETOX TOTAL CAPACITY IMPUTATION FLAG'
   FLAG4_J = 'RES DRUG DETOX TOTAL ACTUAL # MEN IMPUTATION FLAG'
   FLAG4_K = 'RES DRUG DETOX TOTAL ACTUAL # WOMEN IMPUTATION FLAG'
   FLAG4_L = 'RES DRUG DETOX TOTAL ACTUAL # CLIENTS IMPUTATION FLAG'
   FLAG4_M = 'RES DRUG-FREE TOTAL CAPACITY IMPUTATION FLAG'
   FLAG4_N = 'RES DRUG-FREE TOTAL ACTUAL # MEN IMPUTATION FLAG'
   FLAG4_O = 'RES DRUG-FREE TOTAL ACTUAL # WOMEN IMPUTATION FLAG'
   FLAG4_P = 'RES DRUG-FREE TOTAL ACTUAL # CLIENTS IMPUTATION FLAG'
   OPDDMCAP= 'B1A. OUTPT DRG DETOX CAPACITY-MALE'
   OPDDFCAP= 'B1B. OUTPT DRG DETOX CAPACITY-FEMALE'
   OPDDTCAP= 'B1C. OUTPT DRG DETOX CAPACITY-TOTAL'
   OPDDMACT= 'B1D. OUTPT DRG DETOX ACTUAL-MALE'
   OPDDFACT= 'B1E. OUTPT DRG DETOX ACTUAL-FEMALE'
   OPDDTACT= 'B1F. OUTPT DRG DETOX ACTUAL-TOTAL'
   OPDMMCAP= 'B1A. OUTPT DRG MAINT CAPACITY-MALE'
   OPDMFCAP= 'B1B. OUTPT DRG MAINT CAPACITY-FEMALE'
   OPDMTCAP= 'B1C. OUTPT DRG MAINT CAPACITY-TOTAL'
   OPDMMACT= 'B1D. OUTPT DRG MAINT ACTUAL-MALE'
   OPDMFACT= 'B1E. OUTPT DRG MAINT ACTUAL-FEMALE'
   OPDMTACT= 'B1F. OUTPT DRG MAINT ACTUAL-TOTAL'
   OPDFMCAP= 'B1A. OUTPT DRG FREE CAPACITY-MALE'
   OPDFFCAP= 'B1B. OUTPT DRG FREE CAPACITY-FEMALE'
   OPDFTCAP= 'B1C. OUTPT DRG FREE CAPACITY-TOTAL'
   OPDFMACT= 'B1D. OUTPT DRG FREE ACTUAL-MALE'
   OPDFFACT= 'B1E. OUTPT DRG FREE ACTUAL-FEMALE'
   OPDFTACT= 'B1F. OUTPT DRG FREE ACTUAL-TOTAL'
   FLAG5_A = 'OUT-PX DRUG-DETOX TOTAL CAPACITY IMPUTATION FLAG'
   FLAG5_B = 'OUT-PX DRUG-DETOX ACTUAL TOTAL # MEN IMPUTATION FLAG'
   FLAG5_C = 'OUT-PX DRUG-DETOX ACTUAL TOTAL # WOMEN IMPUTATION FLAG'
   FLAG5_D = 'OUT-PX DRUG-DETOX ACTUAL TOTAL # CLIENTS IMPUTATION FLAG'
   FLAG5_E = 'OUT-PX DRUG-MAINTENANCE TOTAL CAPACITY IMPUTATION FLAG'
   FLAG5_F = 'OUT-PX DRUG-MAINTENANCE ACTUAL TOTAL # MEN IMPUTATION FLAG'
   FLAG5_G = 'OUT-PX DRUG-MAINTENANCE ACTUAL TOTAL # WOMEN IMPUTATION FLAG'
   FLAG5_H = 'OUT-PX DRUG-MAINTENANCE ACTUAL TOTAL # CLIENTS IMPUTATION FLAG'
   FLAG5_I = 'OPDF TOTAL CAPACITY IMPUTATION FLAG'
   FLAG5_J = 'OPDF TOTAL ACTUAL # MEN IMPUTATION FLAG'
   FLAG5_K = 'OPDF TOTAL ACTUAL # WOMEN IMPUTATION FLAG'
   FLAG5_L = 'OPDF TOTAL ACTUAL # CLIENTS IMPUTATION FLAG'
   ALCMCAP = 'B1A. ALCHOL TREATMENT CAPACITY-MALE'
   ALCFCAP = 'B1B. ALCHOL TREATMENT CAPACITY-FEMALE'
   ALCTCAP = 'B1C. ALCHOL TREATMENT CAPACITY-TOTAL'
   ALCMACT = 'B1D. ALCHOL TREATMENT ACTUAL-MALE'
   ALCFACT = 'B1E. ALCHOL TREATMENT ACTUAL-FEMALE'
   ALCTACT = 'B1F. ALCHOL TREATMENT ACTUAL-TOTAL'
   TOTMCAP = 'B1A. TOTAL CAPACITY-MALE'
   TOTFCAP = 'B1B. TOTAL CAPACITY-FEMALE'
   TOTALCAP= 'B1C. TOTAL CAPACITY'
   TOTMACT = 'B1D. TOTAL ACTUAL CLIENTS-MALE'
   TOTFACT = 'B1E. TOTAL ACTUAL CLIENTS-FEMALE'
   TOTALACT= 'B1F. TOTAL ACTUAL CLIENTS'
   B2      = 'METHOD USED TO COMPLETE B1'
   B3      = 'B3. MORE APPLICANTS THAN SLOTS'
   B4_NO   = 'B4. WAIT TO ENTER TREATMENT-NUMBER'
   B4_UNIT = 'B4. WAIT TO ENTER TREATMENT-UNIT'
   B5      = 'B5. SYSTEM FOR PLACING ON WAIT-LIST'
   B6      = 'B6. PROCEDURE FOR SCREENING'
   B7      = 'B7. PROCEDURE TO SEE IF PEOPLE WAITING'
   B8      = 'B8. APPLICANT CONTACT FACILITY'
   B9A     = 'B9A. WAIT-LIST CONTAIN NAME'
   B9B     = 'B9B. WAIT-LIST CONTAIN PHONE/ADD'
   WAITTIME= 'WAITING TIME FOR TREATMENT (DAYS)'
   FLAG6_A = 'ALC TOTAL CAPACITY IMPUTATION FLAG'
   FLAG6_B = 'ALC TOTAL ACTUAL # MEN IMPUTATION FLAG'
   FLAG6_C = 'ALC TOTAL ACTUAL # WOMEN IMPUTATION FLAG'
   FLAG6_D = 'ALC TOTAL ACTUAL # CLIENTS IMPUTATION FLAG'
   FLAG6_E = 'TOTAL CAPACITY IMPUTATION FLAG'
   FLAG6_F = 'TOT TOTAL # MEN IMPUTATION FLAG'
   FLAG6_G = 'TOT TOTAL # WOMEN IMPUTATION FLAG'
   FLAG6_H = 'IMPUTATION FLAG - TOTAL ACTUAL #'
   B10_BOX = 'B10. ALCOHOL ONLY BOX CHECKED'
   HIDD_A  = 'B10A. HSP INPT DRG DETOX-TOTAL'
   HIDD_B  = 'B10B. HSP INPT DRG DETOX-1 WEEK'
   HIDD_C  = 'B10C. HSP INPT DRG DETOX-1 MONTH'
   HIDD_D  = 'B10D. HSP INPT DRG DETOX-3 MONTHS'
   HIDD_E  = 'B10E. HSP INPT DRG DETOX- >3 MONTHS'
   HIDF_A  = 'B10A. HSP INPT DRG FREE-TOTAL'
   HIDF_B  = 'B10B. HSP INPT DRG FREE-1 WEEK'
   HIDF_C  = 'B10C. HSP INPT DRG FREE-1 MONTH'
   HIDF_D  = 'B10D. HSP INPT DRG FREE-3 MONTHS'
   HIDF_E  = 'B10E. HSP INPT DRG FREE- >3 MONTHS'
   RSDD_A  = 'B10A. RESIDENTIAL DRG DETOX-TOTAL'
   RSDD_B  = 'B10B. RESIDENTIAL DRG DETOX-1 WEEK'
   RSDD_C  = 'B10C. RESIDENTIAL DRG DETOX-1 MONTH'
   RSDD_D  = 'B10D. RESIDENTIAL DRG DETOX-3 MONTHS'
   RSDD_E  = 'B10E. RESIDENTIAL DRG DETOX- >3 MONTHS'
   RSDF_A  = 'B10A. RESIDENTIAL DRUG FREE-TOTAL'
   RSDF_B  = 'B10B. RESIDENTIAL DRUG FREE-1 WEEK'
   RSDF_C  = 'B10C. RESIDENTIAL DRUG FREE-1 MONTH'
   RSDF_D  = 'B10D. RESIDENTIAL DRUG FREE-3 MONTHS'
   RSDF_E  = 'B10E. RESIDENTIAL DRUG FREE- >3 MONTHS'
   OPDD_A  = 'B10A. OUTPT DRG DETOX-TOTAL'
   OPDD_B  = 'B10B. OUTPT DRG DETOX-1 WEEK'
   OPDD_C  = 'B10C. OUTPT DRG DETOX-1 MONTH'
   OPDD_D  = 'B10D. OUTPT DRG DETOX-3 MONTHS'
   OPDD_E  = 'B10E. OUTPT DRG DETOX- >3 MONTHS'
   OPDM_A  = 'B10A. OUTPT DRUG MAINT-TOTAL'
   OPDM_B  = 'B10B. OUTPT DRUG MAINT-1 WEEK'
   OPDM_C  = 'B10C. OUTPT DRUG MAINT-1 MONTH'
   OPDM_D  = 'B10D. OUTPT DRUG MAINT-3 MONTHS'
   OPDM_E  = 'B10E. OUTPT DRUG MAINT- >3 MONTHS'
   OPDF_A  = 'B10A. OUTPT DRUG FREE-TOTAL'
   OPDF_B  = 'B10B. OUTPT DRUG FREE-1 WEEK'
   OPDF_C  = 'B10C. OUTPT DRUG FREE-1 MONTH'
   OPDF_D  = 'B10D. OUTPT DRUG FREE-3 MONTHS'
   OPDF_E  = 'B10E. OUTPT DRUG FREE- >3 MONTHS'
   TOTAL_A = 'B10A. TOTAL ON WAIT-LIST'
   TOTAL_B = 'B10B. TOTAL FOR LESS THAN 1 WEEK'
   TOTAL_C = 'B10C. TOTAL FOR 1 WEEK-1 MONTH'
   TOTAL_D = 'B10D. TOTAL FOR 1-3 MONTHS'
   TOTAL_E = 'B10E. TOTAL FOR MORE THAN 3 MONTHS'
   B11     = 'METHOD USED TO COMPLETE B10'
   B12A    = 'B12A. PRIORITY - IV DRUG USERS'
   B12B    = 'B12B. PRIORITY - HIV POSITIVE'
   B12C    = 'B12C. PRIORITY - PREGNANT WOMEN'
   B12D    = 'B12D. PRIORITY - POLYDRUG USERS'
   B12E    = 'B12E. PRIORITY - ADOLESCENTS'
   B12F    = 'B12F. PRIORITY - DUAL DIAGNOSIS CLIENT'
   B12G    = 'B12G. PRIORITY - SELF PAY'
   B12H    = 'B12H. PRIORITY - PRIVATE INSURANCE'
   B12I    = 'B12I. PRIORITY - MEDICAID PAY'
   B12J    = 'B12J. PRIORITY - OTHER PUBLIC PAY'
   B13A    = 'B13A. % REFERRED - SELF'
   B13B    = 'B13B. % REFERRED - FAMILY'
   B13C    = 'B13C. % REFERRED - EMPLOYER'
   B13D    = 'B13D. % REFERRED - EAP'
   B13E    = 'B13E. % REFERRED - CRIMINAL JUSTICE'
   B13F    = 'B13F. % REFERRED - HEALTH PROFESSIONAL'
   B13G    = 'B13G. % REFERRED - SCHOOLS'
   B13H    = 'B13H. % REFERRED - CLERGY'
   B13I    = 'B13I. % REFERRED - OTHER'
   B14     = 'METHOD USED TO COMPLETE B13'
   B15A    = 'B15A. % SERVICES - ALCOHOL ABUSE'
   B15B    = 'B15B. % SERVICES - SINGLE DRUG ABUSE'
   B15C    = 'B15C. % SERVICES - SINGLE DRUG/ALCOHOL'
   B15D    = 'B15D. % SERVICES - ABUSE 2 OR MORE DRGS'
   B15E    = 'B15E. % SERVICES - 2 OR MORE DRGS/ALC'
   B16     = 'B16. % IVDU''S'
   B17     = 'B17. % DUAL DIAGNOSIS'
   B18     = 'METHOD USED TO COMPLETE B15-B17'
   FLAG9_A = 'IMPUTATION FLAG - % SELF REFERRED'
   FLAG9_B = 'IMPUTATION FLAG - % FAMILY REFERRED'
   FLAG9_C = 'IMPUTATION FLAG - % EMPLOYER REFERRED'
   FLAG9_D = 'IMPUTATION FLAG - % EMPLOYEE ASSISTANCE PROGRAM REFERRAL'
   FLAG9_E = 'IMPUTATION FLAG - % C.J. SYSTEM BY COURT ORDER REFERRAL'
   FLAG9_F = 'IMPUTATION FLAG - % PHYSICIAN (PRIVATE -HEALTH CTR -ROTHER)'
   FLAG9_G = 'IMPUTATION FLAG - % SCHOOLS'
   FLAG9_H = 'IMPUTATION FLAG - % CLERGY'
   FLAG9_I = 'IMPUTATION FLAG - % OTHER (SPECIFY)'
   FLAG9_J = 'IMPUTATION FLAG - % NO DRUG ABUSE (ALCOHOL ABUSE ONLY)'
   FLAG9_K = 'IMPUTATION FLAG - % SINGLE DRUG ABUSE (NO ALCOHOL ABUSE)'
   FLAG9_L = 'IMPUTATION FLAG - % SINGLE DRUG ABUSE (WITH ALCOHOL ABUSE)'
   FLAG9_M = 'IMPUTATION FLAG - % ABUSE 2 OR MORE DRUGS (NO ALC ABUSE)'
   FLAG9_N = 'IMPUTATION FLAG - % ABUSE 2 OR MORE DRUGS (WITH ALC ABUSE)'
   FLAG9_O = 'IMPUTATION FLAG - % INTERVIENOUS DRUG USERS'
   FLAG9_P = 'IMPUTATION FLAG - % CLIENTS WITH DUAL DIAGNOSIS'
   B19     = 'B19. # CLIENTS RECEIVING METHADONE'
   B20A    = 'B20A. # CLIENTS IN DETOXIFICATION'
   B20B    = 'B20B. # CLIENTS IN MAINTENANCE'
   B21     = 'B21. MAXIMUM DAILY DOSE OF METHADONE'
   B22     = 'B22. MINIMUM DAILY DOSE OF METHADONE'
   B23     = 'B23. AVERAGE DAILY DOSE OF METHADONE'
   B24A    = 'B24A. # OF CLIENTS RECEIVED 1-19 MGS'
   B24B    = 'B24B. # OF CLIENTS RECEIVED 20-39 MGS'
   B24C    = 'B24C. # OF CLIENTS RECEIVED 40-54 MGS'
   B24D    = 'B24D. # OF CLIENTS RECEIVED 55-69 MGS'
   B24E    = 'B24E. # OF CLIENTS RECD 70 MGS OR MORE'
   B25     = 'B25. NO TAKE HOME SUPPLY'
   B25A    = 'B25A. # OF CLIENTS RECD 1 DAY SUPPLY'
   B25B    = 'B25B. # OF CLIENTS RECD 2 DAY SUPPLY'
   B25C    = 'B25C. # OF CLIENTS RECD 3 DAY SUPPLY'
   B25D    = 'B25D. # OF CLIENTS RECD 4 DAY SUPPLY'
   B25E    = 'B25E. # OF CLIENTS RECD 5 DAY SUPPLY'
   B25F    = 'B25F. # OF CLIENTS RECD 6 DAY SUPPLY'
   B25G    = 'B25G. # CLIENTS RECD 7 DAY/MORE SUPPLY'
   B25H    = 'B25H. # OF CLIENTS RECD OTHER SUPPLY'
   B26_NO  = 'B26. TYPICAL LENGTH METH MAINT-NUMBER'
   B26_UNIT= 'B26. TYPICAL LENGTH METH MAINT-UNIT'
   B27_NO  = 'B27. MAXIMUM LENGTH METH MAINT-NUMBER'
   B27_UNIT= 'B27. MAXIMUM LENGTH METH MAINT-UNIT'
   B28A    = 'B28A. DETERMINED MAX TIME - STATE'
   B28B    = 'B28B. DETERMINED MAX TIME - POLICY'
   B28C    = 'B28C. DETERMINED MAX TIME - NEED'
   B28D    = 'B28D. DETERMINED MAX TIME - OTHER'
   FLAG10_A= 'B19 IMPUTATION FLAG'
   FLAG10_B= 'B20A IMPUTATION FLAG'
   FLAG10_C= 'B20B IMPUTATION FLAG'
   FLAG10_D= 'B24A IMPUTATION FLAG'
   FLAG10_E= 'B24B IMPUTATION FLAG'
   FLAG10_F= 'B24C IMPUTATION FLAG'
   FLAG10_G= 'B24D IMPUTATION FLAG'
   FLAG10_H= 'B24E IMPUTATION FLAG'
   FLAG10_I= 'B28A IMPUTATION FLAG'
   FLAG10_J= 'B28B IMPUTATION FLAG'
   FLAG10_K= 'B28C IMPUTATION FLAG'
   FLAG10_L= 'B28D IMPUTATION FLAG'
   SEQ11   = 'SEQUENCE NUMBER'
   HIDD_DEM= 'MODALITY-HSP INPT DRG DETOX'
   HIDF_DEM= 'MODALITY-HSP INPT DRG FREE'
   RSDD_DEM= 'MODALITY-RESIDENTIAL DRG DETOX'
   RSDF_DEM= 'MODALITY-RESIDENTIAL DRG FREE'
   OPDD_DEM= 'MODALITY-OUTPT DRG DETOX'
   OPDM_DEM= 'MODALITY-OUTPT DRG MAINT'
   OPDF_DEM= 'MODALITY-OUTPT DRG FREE'
   ALC_DEM = 'MODALITY-ALCOHOL TREATMENT'
   A_WHITE = 'A. # CLIENTS - WHITE'
   A_BLACK = 'A. # CLIENTS - BLACK'
   A_HISP  = 'A. # CLIENTS - HISPANIC'
   A_ASIAN = 'A. # CLIENTS - ASIAN/PACIFIC ISLANDER'
   A_INDIAN= 'A. # CLIENTS - AM INDIAN/ALASKAN NATIVE'
   A_OTHER = 'A. # CLIENTS - OTHER'
   B_14    = 'B. # CLIENTS - UNDER 15 YRS OLD'
   B_15    = 'B. # CLIENTS - 15-17 YRS OLD'
   B_18    = 'B. # CLIENTS - 18-24 YRS OLD'
   B_25    = 'B. # CLIENTS - 25-34 YRS OLD'
   B_35    = 'B. # CLIENTS - 35-44 YRS OLD'
   B_45    = 'B. # CLIENTS - 45-64 YRS OLD'
   B_65    = 'B. # CLIENTS - 65 AND OLDER'
   C_EMP   = 'C. # CLIENTS - EMPLOYED'
   C_NOTEMP= 'C. # CLIENTS - NOT EMPLOYED'
   DEMXENV2= 'EXPANDED ENVIRONMENT (DEMOGRAPHICS)'
   SEQ12   = 'SEQUENCE NUMBER'
   D_HEROIN= 'D. # CLIENTS - HEROIN/OTHER OPIATES'
   D_CRACK = 'D. # CLIENTS - CRACK'
   D_COCAIN= 'D. # CLIENTS - COCAINE'
   D_BENZ  = 'D. # CLIENTS - BENZODIAZEPINES'
   D_BARB  = 'D. # CLIENTS - BARBITURATES'
   D_AMPH  = 'D. # CLIENTS - AMPHETAMINES'
   D_MARIJ = 'D. # CLIENTS - MARIJUANA/HASHISH'
   D_PCP   = 'D. # CLIENTS - PCP/LSD'
   D_OTH   = 'D. # CLIENTS - OTHER DRUGS'
   E_NOPAY = 'E. # CLIENTS - NO PAYMENT'
   E_SLFPAY= 'E. # CLIENTS - SELF PAYMENT'
   E_PRIVTE= 'E. # CLIENTS - PRIVATE HEALTH INSURANCE'
   E_MEDCD = 'E. # CLIENTS - MEDICAID'
   MEDCR_E = 'E. # CLIENTS - MEDICARE'
   E_OTHER = 'E. # CLIENTS - OTHER PUBLIC PAYMENT'
   METHOD  = 'METHOD USED TO COMPLETE TABLE'
   C1_BOX  = 'C1. ALCOHOL ONLY BOX CHECKED'
   HIDD_C1A= 'C1A. HSP INPT DRG DETOX-ADMITTED'
   HIDD_C1B= 'C1B. HSP INPT DRG DETOX-ENDED'
   HIDD_C1C= 'C1C. HSP INPT DRG DETOX-COMPLETED'
   HIDD_C1D= 'C1D. HSP INPT DRG DETOX-LEFT(OWN)'
   HIDD_C1E= 'C1E. HSP INPT DRG DETOX-LEFT(FACILITY)'
   HIDF_C1A= 'C1A. HSP INPT DRG FREE-ADMITTED'
   HIDF_C1B= 'C1B. HSP INPT DRG FREE-ENDED'
   HIDF_C1C= 'C1C. HSP INPT DRG FREE-COMPLETED'
   HIDF_C1D= 'C1D. HSP INPT DRG FREE-LEFT(OWN)'
   HIDF_C1E= 'C1E. HSP INPT DRG FREE-LEFT(FACILITY)'
   RSDD_C1A= 'C1A. RESIDENTIAL DRG DETOX-ADMITTED'
   RSDD_C1B= 'C1B. RESIDENTIAL DRG DETOX-ENDED'
   RSDD_C1C= 'C1C. RESIDENTIAL DRG DETOX-COMPLETED'
   RSDD_C1D= 'C1D. RESIDENTIAL DRG DETOX-LEFT(OWN)'
   RSDD_C1E= 'C1E. RESIDNTL DRG DETOX-LEFT(FACILITY)'
   RSDF_C1A= 'C1A. RESIDENTIAL DRG FREE-ADMITTED'
   RSDF_C1B= 'C1B. RESIDENTIAL DRG FREE-ENDED'
   RSDF_C1C= 'C1C. RESIDENTIAL DRG FREE-COMPLETED'
   RSDF_C1D= 'C1D. RESIDENTIAL DRG FREE-LEFT(OWN)'
   RSDF_C1E= 'C1E. RESIDNTL DRG FREE-LEFT(FACILITY)'
   FLAG13_A= 'HIDD_C1A IMPUTATION FLAG'
   FLAG13_B= 'HIDD_C1B IMPUTATION FLAG'
   FLAG13_C= 'HIDD_C1C IMPUTATION FLAG'
   FLAG13_D= 'HIDD_C1D IMPUTATION FLAG'
   FLAG13_E= 'HIDD_C1E IMPUTATION FLAG'
   FLAG13_F= 'HIDF_C1A IMPUTATION FLAG'
   FLAG13_G= 'HIDF_C1B IMPUTATION FLAG'
   FLAG13_H= 'HIDF_C1C IMPUTATION FLAG'
   FLAG13_I= 'HIDF_C1D IMPUTATION FLAG'
   FLAG13_J= 'HIDF_C1E IMPUTATION FLAG'
   FLAG13_K= 'RSDD_C1A IMPUTATION FLAG'
   FLAG13_L= 'RSDD_C1B IMPUTATION FLAG'
   FLAG13_M= 'RSDD_C1C IMPUTATION FLAG'
   FLAG13_N= 'RSDD_C1D IMPUTATION FLAG'
   FLAG13_O= 'RSDD_C1E IMPUTATION FLAG'
   FLAG13_P= 'RSDF_C1A IMPUTATION FLAG'
   FLAG13_Q= 'RSDF_C1B IMPUTATION FLAG'
   FLAG13_R= 'RSDF_C1C IMPUTATION FLAG'
   FLAG13_S= 'RSDF_C1D IMPUTATION FLAG'
   FLAG13_T= 'RSDF_C1E IMPUTATION FLAG'
   OPDD_C1A= 'C1A. OUTPT DRG DETOX-ADMITTED'
   OPDD_C1B= 'C1B. OUTPT DRG DETOX-ENDED'
   OPDD_C1C= 'C1C. OUTPT DRG DETOX-COMPLETED'
   OPDD_C1D= 'C1D. OUTPT DRG DETOX-LEFT(OWN)'
   OPDD_C1E= 'C1E. OUTPT DRG DETOX-LEFT(FACILITY)'
   OPDM_C1A= 'C1A. OUTPT DRG MAINT-ADMITTED'
   OPDM_C1B= 'C1B. OUTPT DRG MAINT-ENDED'
   OPDM_C1C= 'C1C. OUTPT DRG MAINT-COMPLETED'
   OPDM_C1D= 'C1D. OUTPT DRG MAINT-LEFT(OWN)'
   OPDM_C1E= 'C1E. OUTPT DRG MAINT-LEFT(FACILITY)'
   OPDF_C1A= 'C1A. OUTPT DRG FREE-ADMITTED'
   OPDF_C1B= 'C1B. OUTPT DRG FREE-ENDED'
   OPDF_C1C= 'C1C. OUTPT DRG FREE-COMPLETED'
   OPDF_C1D= 'C1D. OUTPT DRG FREE-LEFT(OWN)'
   OPDF_C1E= 'C1E. OUTPT DRG FREE-LEFT(FACILITY)'
   TOT_C1A = 'C1A. TOTAL CLIENTS-ADMITTED'
   TOT_C1B = 'C1B. TOTAL CLIENTS-ENDED TRTMENT'
   TOT_C1C = 'C1C. TOTAL CLIENTS-COMPLETED TRTMENT'
   TOT_C1D = 'C1D. TOTAL CLIENTS-LEFT TRTMENT(OWN)'
   TOT_C1E = 'C1E. TOTAL CLIENTS-LFT TRTMNT(FACLTY)'
   C2      = 'METHOD USED TO COMPLETE TABLE C1'
   FLAG14_A= 'OPDD_C1A IMPUTATION FLAG'
   FLAG14_B= 'OPDD_C1B IMPUTATION FLAG'
   FLAG14_C= 'OPDD_C1C IMPUTATION FLAG'
   FLAG14_D= 'OPDD_C1D IMPUTATION FLAG'
   FLAG14_E= 'OPDD_C1E IMPUTATION FLAG'
   FLAG14_F= 'OPDM_C1A IMPUTATION FLAG'
   FLAG14_G= 'OPDM_C1B IMPUTATION FLAG'
   FLAG14_H= 'OPDM_C1C IMPUTATION FLAG'
   FLAG14_I= 'OPDM_C1D IMPUTATION FLAG'
   FLAG14_J= 'OPDM_C1E IMPUTATION FLAG'
   FLAG14_K= 'OPDF_C1A IMPUTATION FLAG'
   FLAG14_L= 'OPDF_C1B IMPUTATION FLAG'
   FLAG14_M= 'OPDF_C1C IMPUTATION FLAG'
   FLAG14_N= 'OPDF_C1D IMPUTATION FLAG'
   FLAG14_O= 'OPDF_C1E IMPUTATION FLAG'
   FLAG14_P= 'TOT_C1A IMPUTATION FLAG'
   FLAG14_Q= 'TOT_C1B IMPUTATION FLAG'
   FLAG14_R= 'TOT_C1C IMPUTATION FLAG'
   FLAG14_S= 'TOT_C1D IMPUTATION FLAG'
   FLAG14_T= 'TOT_C1E IMPUTATION FLAG'
   HIDDPNO = 'C3A. HSPINPT DRG DETOX-PLAN LNGTH(NO)'
   HIDDPUNT= 'C3 - HIDD PLANNED LENGTH OF TX - UNIT'
   HIDDANO = 'C3A. HSPINPT DRG DETOX-ACTL LNGTH(NO)'
   HIDDAUNT= 'C3 - HIDD ACTUAL LENGTH OF TX - UNIT'
   HIDFPNO = 'C3A. HSPINPT DRG FREE-PLAN LNGTH(NO)'
   HIDFPUNT= 'C3 - HIDF PLANNED LENGTH OF TX - UNIT'
   HIDFANO = 'C3A. HSPINPT DRG FREE-ACTL LNGTH(NO)'
   HIDFAUNT= 'C3 - HIDF ACTUAL LENGTH OF TX - UNIT'
   RSDDPNO = 'C3B. RESDNTL DRG DETOX-PLAN LNGTH(NO)'
   RSDDPUNT= 'C3 - RSDD PLANNED LENGTH OF TX - UNIT'
   RSDDANO = 'C3B. RESDNTL DRG DETOX-ACTL LNGTH(NO)'
   RSDDAUNT= 'C3 - RSDD ACTUAL LENGTH OF TX - UNIT'
   RSDFPNO = 'C3B. RSDNTL DRG FREE-PLAN LNGTH(NO)'
   RSDFPUNT= 'C3 - RSDF PLANNED LENGTH OF TX - UNIT'
   RSDFANO = 'C3B. RSDNTL DRG FREE-ACTL LNGTH(NO)'
   RSDFAUNT= 'C3 - RSDF ACTUAL LENGTH OF TX - UNIT'
   OPDDPNO = 'C3C. OUTPT DRG DETOX-PLAN LNGTH(NO)'
   OPDDPUNT= 'C3 - OPDD PLANNED LENGTH OF TX - UNIT'
   OPDDANO = 'C3C. OUTPT DRG DETOX-ACTL LNGTH(NO)'
   OPDDAUNT= 'C3 - OPDD ACTUAL LENGTH OF TX - UNIT'
   OPDMPNO = 'C3C. OUTPT DRG MAINT-PLAN LNGTH(NO)'
   OPDMPUNT= 'C3 - OPDM PLANNED LENGTH OF TX - UNIT'
   OPDMANO = 'C3C. OUTPT DRG MAINT-ACTL LNGTH(NO)'
   OPDMAUNT= 'C3 - OPDM ACTUAL LENGTH OF TX - UNIT'
   OPDFPNO = 'C3C. OUTPT DRG FREE-PLAN LNGTH(NO)'
   OPDFPUNT= 'C3 - OPDF PLANNED LENGTH OF TX - UNIT'
   OPDFANO = 'C3C. OUTPT DRG FREE-ACTL LNGTH(NO)'
   OPDFAUNT= 'C3 - OPDF ACTUAL LENGTH OF TX - UNIT'
   C4      = 'METHOD USED TO COMPLETE QUESTION C3'
   C5      = 'C5. FACILITY TREAT PREGNANT FEMALES'
   C6      = 'C6. HOW MANY PREGNANT FEMALES TREATED'
   C7A     = 'C7A. SERVICES-FAMILY PLAN EDUC'
   C7B     = 'C7B. SERVICES-PRENATAL CARE'
   C7C     = 'C7C. SERVICES-PRENATAL EDUCATION'
   C7D     = 'C7D. SERVICES-AFTER CARE'
   C7E     = 'C7E. SERVICES-BIRTHING'
   C7F     = 'C7F. SERVICES-CHILD CARE'
   C7G     = 'C7G. SERVICES-PARENTING EDUC'
   C7H     = 'C7H. SERVICES-HOUSING SERVICES'
   C7I     = 'C7I. SERVICES-VOCATIONAL EDUC'
   C7J     = 'C7J. SERVICES-TRANSPORTATION'
   C8A     = 'C8A. REASON-NO PREGNANT FEMALES'
   C8B     = 'C8B. REASON-STAFF NOT TRAINED'
   C8C     = 'C8C. REASON-NOT PHYSICALLY EQUIPPED'
   C8D     = 'C8D. REASON-OTHER'
   C9      = 'C9. REFER PREGNANT FEMALES'
   C10_REF = 'C10. # PREGNANT FEMALES REFERRED'
   C11_REF = 'C11. REFER TO PRENATAL CARE SERVICES'
   C12_TST = 'C12. CONDUCT PREGNANCY TESTS'
   C13     = 'C13. # CLIENTS TESTED POSITIVE'
   C14     = 'C14. CONDUCT HIV/AIDS TESTS'
   C16     = 'C16. CONDUCT BLOOD ALCOHOL TESTS'
   C17     = 'C17. CONDUCT ANY DRUG TESTS'
   C18A    = 'C18A. CONDUCT URINE TESTS'
   C18B    = 'C18B. CONDUCT BLOOD TESTS'
   C18C    = 'C18C. CONDUCT OTHER TESTS'
   C19A    = 'C19A. ANALYSIS DONE ON PREMISES'
   C19B    = 'C19B. ANALYSIS CONTRACTED TO NIDA LAB'
   C19C    = 'C19C. ANALYSIS CONTRACTED TO OTHER LAB'
   C20A_ADM= 'C20A. ADMISSION - MARIJUANA/HASHISH'
   C20A_TRT= 'C20A. DURING TRTMNT - MARIJUANA/HASH'
   C20A_DIS= 'C20A. DISCHARGE - MARIJUANA/HASHISH'
   C20B_ADM= 'C20B. ADMISSION - COCAINE'
   C20B_TRT= 'C20B. DURING TRTMNT - COCAINE'
   C20B_DIS= 'C20B. DISCHARGE - COCAINE'
   C20C_ADM= 'C20C. ADMISSION - HEROIN/OPIATES'
   C20C_TRT= 'C20C. DURING TRTMNT - HEROIN/OPIATES'
   C20C_DIS= 'C20C. DISCHARGE - HEROIN/OPIATES'
   C20D_ADM= 'C20D. ADMISSION - BARBITURATES'
   C20D_TRT= 'C20D. DURING TRTMNT - BARBITURATES'
   C20D_DIS= 'C20D. DISCHARGE - BARBITURATES'
   C20E_ADM= 'C20E. ADMISSION - BENZODIAZEPINES'
   C20E_TRT= 'C20E. DURING TRTMNT - BENZODIAZEPINES'
   C20E_DIS= 'C20E. DISCHARGE - BENZODIAZEPINES'
   C20F_ADM= 'C20F. ADMISSION - AMPHETAMINES'
   C20F_TRT= 'C20F. DURING TRTMNT - AMPHETAMINES'
   C20F_DIS= 'C20F. DISCHARGE - AMPHETAMINES'
   C20G_ADM= 'C20G. ADMISSION - PCP'
   C20G_TRT= 'C20G. DURING TRTMNT - PCP'
   C20G_DIS= 'C20G. DISCHARGE - PCP'
   C20H_ADM= 'C20H. ADMISSION - LSD'
   C20H_TRT= 'C20H. DURING TRTMNT - LSD'
   C20H_DIS= 'C20H. DISCHARGE - LSD'
   C20I_ADM= 'C20I. ADMISSION - OTHER'
   C20I_TRT= 'C20I. DURING TRTMNT - OTHER'
   C20I_DIS= 'C20I. DISCHARGE - OTHER'
   C21     = 'C21. TESTING DONE AT REGULAR INTERVALS'
   C22_NO  = 'C22. FREQ/INTERVAL OF TESTING-# TIMES'
   C22_UNIT= 'C22. FREQ/INTERVAL OF TESTING-UNIT'
   C23     = 'C23. TESTING ADJUSTED FOR CLIENT NEED'
   C24     = 'C24. TESTING DONE RANDOMLY'
   C25     = 'C25. OFFER PROGRAM FOR SPEC POPULTION'
   C26     = 'C26. PROGRAMS OFFERED SPECIFIED'
   C27A    = 'C27A. OFFER MEDICAL CARE'
   C27B    = 'C27B. OFFER LEGAL COUNSELING'
   C27C    = 'C27C. OFFER OUTREACH'
   C27D    = 'C27D. OFFER HOUSING SERVICES'
   C27E    = 'C27E. OFFER VOCATIONAL EDUCATION'
   C27F    = 'C27F. OFFER TRANSPORTATION'
   C27G    = 'C27G. OFFER CRISES INTERVENTION'
   C27H    = 'C27H. OFFER FAMILY/FRIENDS COUNSELING'
   C27I    = 'C27I. OFFER AFTER CARE'
   C27J    = 'C27J. OFFER FOLLOWUP APPOINTMENTS'
   C27K    = 'C27K. OFFER RELAPSE PREVENTION'
   C27L    = 'C27L. OFFER OTHER SERVICES'
   D1_BOX  = 'D1. ALCOHOL ONLY BOX CHECKED'
   HIDD_D1 = 'D1A. HSP INPT DRG DETOX - COSTS'
   HIDF_D1 = 'D1A. HSP INPT DRG FREE - COSTS'
   RSDD_D1 = 'D1B. RESIDENTIAL DRUG DETOX - COSTS'
   RSDF_D1 = 'D1B. RESIDENTIAL DRUG FREE - COSTS'
   OPDD_D1 = 'D1C. OUTPT DRUG DETOX - COSTS'
   OPDM_D1 = 'D1C. OUTPT DRUG MAINT - COSTS'
   OPDF_D1 = 'D1C. OUTPT DRUG FREE - COSTS'
   TOTAL_D1= 'D1D. TOTAL DRUG TREATMENT COSTS'
   D2      = 'METHOD USED TO COMPLETE QUESTION D1'
   FLAG17_A= 'TOTAL_D1 IMPUTATION FLAG'
   D3      = 'D3. PROGRAM CERTIFIED BY MEDICAID'
   D4      = 'D4. TOTAL $ RECEIVED FROM MEDICAID'
   D5      = 'D5. # CLIENTS REC''D $ FROM MEDICAID'
   D6      = 'D6. TOTAL REVENUES'
   D7A     = 'D7A. % INCOME FROM ADAMHA FUNDS'
   D7B     = 'D7B. % INCOME FROM OTH ST ALC/DRG FUNDS'
   D7C     = 'D7C. % INCOME FROM OTHER ST FUNDS'
   D7D     = 'D7D. % INCOME FROM LOCAL FUNDS'
   D7E     = 'D7E. % INCOME FROM CLIENT FEES'
   D7F     = 'D7F. % INCOME FROM PREPAID PLANS'
   D7G     = 'D7G. % INCOME FROM OTHER PRIVATE INS'
   D7H     = 'D7H. % INCOME FROM MEDICAID'
   D7I     = 'D7I. % INCOME FROM MEDICARE'
   D7J     = 'D7J. % INCOME FROM CHAMPUS'
   D7K     = 'D7K. % INCOME FROM PHILANTHROPY'
   D7L     = 'D7L. % INCOME FROM OTHER SOURCES'
   KEYBATCH= 'BATCH NUMBER'
   FLAG18_A= 'D6 IMPUTATION FLAG'
   FLAG18_B= 'D7A TOTAL IMPUTATION FLAG'
   FLAG18_C= 'D7B IMPUTATION FLAG'
   FLAG18_D= 'D7C IMPUTATION FLAG'
   FLAG18_E= 'D7D IMPUTATION FLAG'
   FLAG18_F= 'D7E IMPUTATION FLAG'
   FLAG18_G= 'D7F IMPUTATION FLAG'
   FLAG18_H= 'D7G IMPUTATION FLAG'
   FLAG18_I= 'D7H IMPUTATION FLAG'
   FLAG18_J= 'D7I IMPUTATION FLAG'
   FLAG18_K= 'D7J IMPUTATION FLAG'
   FLAG18_L= 'D7K IMPUTATION FLAG'
   FLAG18_M= 'D7L IMPUTATION FLAG'
   NFINWT0 = 'FIN NONRESPONS ADJUSTED SELECTION WGT'
   RPWT1   = 'PHASE 1 - REPLICATE WEIGHT 1'
   RPWT2   = 'PHASE 1 - REPLICATE WEIGHT 2'
   RPWT3   = 'PHASE 1 - REPLICATE WEIGHT 3'
   RPWT4   = 'PHASE 1 - REPLICATE WEIGHT 4'
   RPWT5   = 'PHASE 1 - REPLICATE WEIGHT 5'
   RPWT6   = 'PHASE 1 - REPLICATE WEIGHT 6'
   RPWT7   = 'PHASE 1 - REPLICATE WEIGHT 7'
   RPWT8   = 'PHASE 1 - REPLICATE WEIGHT 8'
   RPWT9   = 'PHASE 1 - REPLICATE WEIGHT 9'
   RPWT10  = 'PHASE 1 - REPLICATE WEIGHT 10'
   RPWT11  = 'PHASE 1 - REPLICATE WEIGHT 11'
   RPWT12  = 'PHASE 1 - REPLICATE WEIGHT 12'
   RPWT13  = 'PHASE 1 - REPLICATE WEIGHT 13'
   RPWT14  = 'PHASE 1 - REPLICATE WEIGHT 14'
   RPWT15  = 'PHASE 1 - REPLICATE WEIGHT 15'
   RPWT16  = 'PHASE 1 - REPLICATE WEIGHT 16'
   RPWT17  = 'PHASE 1 - REPLICATE WEIGHT 17'
   RPWT18  = 'PHASE 1 - REPLICATE WEIGHT 18'
   RPWT19  = 'PHASE 1 - REPLICATE WEIGHT 19'
   RPWT20  = 'PHASE 1 - REPLICATE WEIGHT 20'
   RPWT21  = 'PHASE 1 - REPLICATE WEIGHT 21'
   RPWT22  = 'PHASE 1 - REPLICATE WEIGHT 22'
   RPWT23  = 'PHASE 1 - REPLICATE WEIGHT 23'
   RPWT24  = 'PHASE 1 - REPLICATE WEIGHT 24'
   RPWT25  = 'PHASE 1 - REPLICATE WEIGHT 25'
   RPWT26  = 'PHASE 1 - REPLICATE WEIGHT 26'
   RPWT27  = 'PHASE 1 - REPLICATE WEIGHT 27'
   RPWT28  = 'PHASE 1 - REPLICATE WEIGHT 28'
   RPWT29  = 'PHASE 1 - REPLICATE WEIGHT 29'
   RPWT30  = 'PHASE 1 - REPLICATE WEIGHT 30'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (OBS_NUM <= -1) THEN OBS_NUM = .;
   IF (CRP_MO1 <= -1) THEN CRP_MO1 = .;
   IF (CRP_DA1 <= -1) THEN CRP_DA1 = .;
   IF (CRP_YR1 <= -1) THEN CRP_YR1 = .;
   IF (CRP_MO2 <= -1) THEN CRP_MO2 = .;
   IF (CRP_DA2 <= -1) THEN CRP_DA2 = .;
   IF (CRP_YR2 <= -1) THEN CRP_YR2 = .;
   IF (CLENGTH <= -1) THEN CLENGTH = .;
   IF (FRP_MO1 <= -1) THEN FRP_MO1 = .;
   IF (FRP_DA1 <= -1) THEN FRP_DA1 = .;
   IF (FRP_YR1 <= -1) THEN FRP_YR1 = .;
   IF (FRP_MO2 <= -1) THEN FRP_MO2 = .;
   IF (FRP_DA2 <= -1) THEN FRP_DA2 = .;
   IF (FRP_YR2 <= -1) THEN FRP_YR2 = .;
   IF (FLENGTH <= -1) THEN FLENGTH = .;
   IF (A1_NO <= -1) THEN A1_NO = .;
   IF (A1_UNIT <= -1) THEN A1_UNIT = .;
   IF (A2A <= -1) THEN A2A = .;
   IF (A2B <= -1) THEN A2B = .;
   IF (A2C <= -1) THEN A2C = .;
   IF (A2D <= -1) THEN A2D = .;
   IF (A2E <= -1) THEN A2E = .;
   IF (A3A <= -1) THEN A3A = .;
   IF (A3B <= -1) THEN A3B = .;
   IF (A3C <= -1) THEN A3C = .;
   IF (A3D <= -1) THEN A3D = .;
   IF (A3E <= -1) THEN A3E = .;
   IF (A4A <= -1) THEN A4A = .;
   IF (A4B <= -1) THEN A4B = .;
   IF (A4C <= -1) THEN A4C = .;
   IF (A4D <= -1) THEN A4D = .;
   IF (A4E <= -1) THEN A4E = .;
   IF (A4F <= -1) THEN A4F = .;
   IF (A5A <= -1) THEN A5A = .;
   IF (A5B <= -1) THEN A5B = .;
   IF (HIDD_A6 <= -1) THEN HIDD_A6 = .;
   IF (HIDM_A6 <= -1) THEN HIDM_A6 = .;
   IF (HIDF_A6 <= -1) THEN HIDF_A6 = .;
   IF (RSDD_A6 <= -1) THEN RSDD_A6 = .;
   IF (RSDM_A6 <= -1) THEN RSDM_A6 = .;
   IF (RSDF_A6 <= -1) THEN RSDF_A6 = .;
   IF (OPDD_A6 <= -1) THEN OPDD_A6 = .;
   IF (OPDM_A6 <= -1) THEN OPDM_A6 = .;
   IF (OPDF_A6 <= -1) THEN OPDF_A6 = .;
   IF (ALC_A6 <= -1) THEN ALC_A6 = .;
   IF (CORRFAC <= -1) THEN CORRFAC = .;
   IF (ALCHONLY <= -1) THEN ALCHONLY = .;
   IF (SEQ11CNT <= -1) THEN SEQ11CNT = .;
   IF (SEQ12CNT <= -1) THEN SEQ12CNT = .;
   IF (NUMMOD <= -1) THEN NUMMOD = .;
   IF (MOD <= -1) THEN MOD = .;
   IF (OWN <= -1) THEN OWN = .;
   IF (ENV <= -1) THEN ENV = .;
   IF (XENV <= -1) THEN XENV = .;
   IF (STRATUM <= -1) THEN STRATUM = .;
   IF (REGION <= -1) THEN REGION = .;
   IF (IMPFLAG <= -1) THEN IMPFLAG = .;
   IF (A7_BOX <= -1) THEN A7_BOX = .;
   IF (A7A_FT <= -1) THEN A7A_FT = .;
   IF (A7A_PT <= -1) THEN A7A_PT = .;
   IF (A7A_CON <= -1) THEN A7A_CON = .;
   IF (A7A_CERT <= -1) THEN A7A_CERT = .;
   IF (A7B_FT <= -1) THEN A7B_FT = .;
   IF (A7B_PT <= -1) THEN A7B_PT = .;
   IF (A7B_CON <= -1) THEN A7B_CON = .;
   IF (A7B_CERT <= -1) THEN A7B_CERT = .;
   IF (A7C_FT <= -1) THEN A7C_FT = .;
   IF (A7C_PT <= -1) THEN A7C_PT = .;
   IF (A7C_CON <= -1) THEN A7C_CON = .;
   IF (A7C_CERT <= -1) THEN A7C_CERT = .;
   IF (A7D_FT <= -1) THEN A7D_FT = .;
   IF (A7D_PT <= -1) THEN A7D_PT = .;
   IF (A7D_CON <= -1) THEN A7D_CON = .;
   IF (A7D_CERT <= -1) THEN A7D_CERT = .;
   IF (A7E_FT <= -1) THEN A7E_FT = .;
   IF (A7E_PT <= -1) THEN A7E_PT = .;
   IF (A7E_CON <= -1) THEN A7E_CON = .;
   IF (A7E_CERT <= -1) THEN A7E_CERT = .;
   IF (A7F_FT <= -1) THEN A7F_FT = .;
   IF (A7F_PT <= -1) THEN A7F_PT = .;
   IF (A7F_CON <= -1) THEN A7F_CON = .;
   IF (A7F_CERT <= -1) THEN A7F_CERT = .;
   IF (A7G_FT <= -1) THEN A7G_FT = .;
   IF (A7G_PT <= -1) THEN A7G_PT = .;
   IF (A7G_CON <= -1) THEN A7G_CON = .;
   IF (A7G_CERT <= -1) THEN A7G_CERT = .;
   IF (A7H_FT <= -1) THEN A7H_FT = .;
   IF (A7H_PT <= -1) THEN A7H_PT = .;
   IF (A7H_CON <= -1) THEN A7H_CON = .;
   IF (A7H_CERT <= -1) THEN A7H_CERT = .;
   IF (A7I_FT <= -1) THEN A7I_FT = .;
   IF (A7I_PT <= -1) THEN A7I_PT = .;
   IF (A7I_CON <= -1) THEN A7I_CON = .;
   IF (A7I_CERT <= -1) THEN A7I_CERT = .;
   IF (A7J_FT <= -1) THEN A7J_FT = .;
   IF (A7J_PT <= -1) THEN A7J_PT = .;
   IF (A7J_CON <= -1) THEN A7J_CON = .;
   IF (A7J_CERT <= -1) THEN A7J_CERT = .;
   IF (A7K_FT <= -1) THEN A7K_FT = .;
   IF (A7K_PT <= -1) THEN A7K_PT = .;
   IF (A7K_CON <= -1) THEN A7K_CON = .;
   IF (A7K_CERT <= -1) THEN A7K_CERT = .;
   IF (A7L_FT <= -1) THEN A7L_FT = .;
   IF (A7L_PT <= -1) THEN A7L_PT = .;
   IF (A7L_CON <= -1) THEN A7L_CON = .;
   IF (A7L_CERT <= -1) THEN A7L_CERT = .;
   IF (A7M_FT <= -1) THEN A7M_FT = .;
   IF (A7M_PT <= -1) THEN A7M_PT = .;
   IF (A7M_CON <= -1) THEN A7M_CON = .;
   IF (A7M_CERT <= -1) THEN A7M_CERT = .;
   IF (A8 <= -1) THEN A8 = .;
   IF (A9 <= -1) THEN A9 = .;
   IF (A10 <= -1) THEN A10 = .;
   IF (A11 <= -1) THEN A11 = .;
   IF (B1_BOX <= -1) THEN B1_BOX = .;
   IF (HIDDMCAP <= -1) THEN HIDDMCAP = .;
   IF (HIDDFCAP <= -1) THEN HIDDFCAP = .;
   IF (HIDDTCAP <= -1) THEN HIDDTCAP = .;
   IF (HIDDMACT <= -1) THEN HIDDMACT = .;
   IF (HIDDFACT <= -1) THEN HIDDFACT = .;
   IF (HIDDTACT <= -1) THEN HIDDTACT = .;
   IF (HIDFMCAP <= -1) THEN HIDFMCAP = .;
   IF (HIDFFCAP <= -1) THEN HIDFFCAP = .;
   IF (HIDFTCAP <= -1) THEN HIDFTCAP = .;
   IF (HIDFMACT <= -1) THEN HIDFMACT = .;
   IF (HIDFFACT <= -1) THEN HIDFFACT = .;
   IF (HIDFTACT <= -1) THEN HIDFTACT = .;
   IF (RSDDMCAP <= -1) THEN RSDDMCAP = .;
   IF (RSDDFCAP <= -1) THEN RSDDFCAP = .;
   IF (RSDDTCAP <= -1) THEN RSDDTCAP = .;
   IF (RSDDMACT <= -1) THEN RSDDMACT = .;
   IF (RSDDFACT <= -1) THEN RSDDFACT = .;
   IF (RSDDTACT <= -1) THEN RSDDTACT = .;
   IF (RSDFMCAP <= -1) THEN RSDFMCAP = .;
   IF (RSDFFCAP <= -1) THEN RSDFFCAP = .;
   IF (RSDFTCAP <= -1) THEN RSDFTCAP = .;
   IF (RSDFMACT <= -1) THEN RSDFMACT = .;
   IF (RSDFFACT <= -1) THEN RSDFFACT = .;
   IF (RSDFTACT <= -1) THEN RSDFTACT = .;
   IF (FLAG4_A <= -1) THEN FLAG4_A = .;
   IF (FLAG4_B <= -1) THEN FLAG4_B = .;
   IF (FLAG4_C <= -1) THEN FLAG4_C = .;
   IF (FLAG4_D <= -1) THEN FLAG4_D = .;
   IF (FLAG4_E <= -1) THEN FLAG4_E = .;
   IF (FLAG4_F <= -1) THEN FLAG4_F = .;
   IF (FLAG4_G <= -1) THEN FLAG4_G = .;
   IF (FLAG4_H <= -1) THEN FLAG4_H = .;
   IF (FLAG4_I <= -1) THEN FLAG4_I = .;
   IF (FLAG4_J <= -1) THEN FLAG4_J = .;
   IF (FLAG4_K <= -1) THEN FLAG4_K = .;
   IF (FLAG4_L <= -1) THEN FLAG4_L = .;
   IF (FLAG4_M <= -1) THEN FLAG4_M = .;
   IF (FLAG4_N <= -1) THEN FLAG4_N = .;
   IF (FLAG4_O <= -1) THEN FLAG4_O = .;
   IF (FLAG4_P <= -1) THEN FLAG4_P = .;
   IF (OPDDMCAP <= -1) THEN OPDDMCAP = .;
   IF (OPDDFCAP <= -1) THEN OPDDFCAP = .;
   IF (OPDDTCAP <= -1) THEN OPDDTCAP = .;
   IF (OPDDMACT <= -1) THEN OPDDMACT = .;
   IF (OPDDFACT <= -1) THEN OPDDFACT = .;
   IF (OPDDTACT <= -1) THEN OPDDTACT = .;
   IF (OPDMMCAP <= -1) THEN OPDMMCAP = .;
   IF (OPDMFCAP <= -1) THEN OPDMFCAP = .;
   IF (OPDMTCAP <= -1) THEN OPDMTCAP = .;
   IF (OPDMMACT <= -1) THEN OPDMMACT = .;
   IF (OPDMFACT <= -1) THEN OPDMFACT = .;
   IF (OPDMTACT <= -1) THEN OPDMTACT = .;
   IF (OPDFMCAP <= -1) THEN OPDFMCAP = .;
   IF (OPDFFCAP <= -1) THEN OPDFFCAP = .;
   IF (OPDFTCAP <= -1) THEN OPDFTCAP = .;
   IF (OPDFMACT <= -1) THEN OPDFMACT = .;
   IF (OPDFFACT <= -1) THEN OPDFFACT = .;
   IF (OPDFTACT <= -1) THEN OPDFTACT = .;
   IF (FLAG5_A <= -1) THEN FLAG5_A = .;
   IF (FLAG5_B <= -1) THEN FLAG5_B = .;
   IF (FLAG5_C <= -1) THEN FLAG5_C = .;
   IF (FLAG5_D <= -1) THEN FLAG5_D = .;
   IF (FLAG5_E <= -1) THEN FLAG5_E = .;
   IF (FLAG5_F <= -1) THEN FLAG5_F = .;
   IF (FLAG5_G <= -1) THEN FLAG5_G = .;
   IF (FLAG5_H <= -1) THEN FLAG5_H = .;
   IF (FLAG5_I <= -1) THEN FLAG5_I = .;
   IF (FLAG5_J <= -1) THEN FLAG5_J = .;
   IF (FLAG5_K <= -1) THEN FLAG5_K = .;
   IF (FLAG5_L <= -1) THEN FLAG5_L = .;
   IF (ALCMCAP <= -1) THEN ALCMCAP = .;
   IF (ALCFCAP <= -1) THEN ALCFCAP = .;
   IF (ALCTCAP <= -1) THEN ALCTCAP = .;
   IF (ALCMACT <= -1) THEN ALCMACT = .;
   IF (ALCFACT <= -1) THEN ALCFACT = .;
   IF (ALCTACT <= -1) THEN ALCTACT = .;
   IF (TOTMCAP <= -1) THEN TOTMCAP = .;
   IF (TOTFCAP <= -1) THEN TOTFCAP = .;
   IF (TOTALCAP <= -1) THEN TOTALCAP = .;
   IF (TOTMACT <= -1) THEN TOTMACT = .;
   IF (TOTFACT <= -1) THEN TOTFACT = .;
   IF (TOTALACT <= -1) THEN TOTALACT = .;
   IF (B2 <= -1) THEN B2 = .;
   IF (B3 <= -1) THEN B3 = .;
   IF (B4_NO <= -1) THEN B4_NO = .;
   IF (B4_UNIT <= -1) THEN B4_UNIT = .;
   IF (B5 <= -1) THEN B5 = .;
   IF (B6 <= -1) THEN B6 = .;
   IF (B7 <= -1) THEN B7 = .;
   IF (B8 <= -1) THEN B8 = .;
   IF (B9A <= -1) THEN B9A = .;
   IF (B9B <= -1) THEN B9B = .;
   IF (WAITTIME <= -1.00) THEN WAITTIME = .;
   IF (FLAG6_A <= -1) THEN FLAG6_A = .;
   IF (FLAG6_B <= -1) THEN FLAG6_B = .;
   IF (FLAG6_C <= -1) THEN FLAG6_C = .;
   IF (FLAG6_D <= -1) THEN FLAG6_D = .;
   IF (FLAG6_E <= -1) THEN FLAG6_E = .;
   IF (FLAG6_F <= -1) THEN FLAG6_F = .;
   IF (FLAG6_G <= -1) THEN FLAG6_G = .;
   IF (FLAG6_H <= -1) THEN FLAG6_H = .;
   IF (B10_BOX <= -1) THEN B10_BOX = .;
   IF (HIDD_A <= -1) THEN HIDD_A = .;
   IF (HIDD_B <= -1) THEN HIDD_B = .;
   IF (HIDD_C <= -1) THEN HIDD_C = .;
   IF (HIDD_D <= -1) THEN HIDD_D = .;
   IF (HIDD_E <= -1) THEN HIDD_E = .;
   IF (HIDF_A <= -1) THEN HIDF_A = .;
   IF (HIDF_B <= -1) THEN HIDF_B = .;
   IF (HIDF_C <= -1) THEN HIDF_C = .;
   IF (HIDF_D <= -1) THEN HIDF_D = .;
   IF (HIDF_E <= -1) THEN HIDF_E = .;
   IF (RSDD_A <= -1) THEN RSDD_A = .;
   IF (RSDD_B <= -1) THEN RSDD_B = .;
   IF (RSDD_C <= -1) THEN RSDD_C = .;
   IF (RSDD_D <= -1) THEN RSDD_D = .;
   IF (RSDD_E <= -1) THEN RSDD_E = .;
   IF (RSDF_A <= -1) THEN RSDF_A = .;
   IF (RSDF_B <= -1) THEN RSDF_B = .;
   IF (RSDF_C <= -1) THEN RSDF_C = .;
   IF (RSDF_D <= -1) THEN RSDF_D = .;
   IF (RSDF_E <= -1) THEN RSDF_E = .;
   IF (OPDD_A <= -1) THEN OPDD_A = .;
   IF (OPDD_B <= -1) THEN OPDD_B = .;
   IF (OPDD_C <= -1) THEN OPDD_C = .;
   IF (OPDD_D <= -1) THEN OPDD_D = .;
   IF (OPDD_E <= -1) THEN OPDD_E = .;
   IF (OPDM_A <= -1) THEN OPDM_A = .;
   IF (OPDM_B <= -1) THEN OPDM_B = .;
   IF (OPDM_C <= -1) THEN OPDM_C = .;
   IF (OPDM_D <= -1) THEN OPDM_D = .;
   IF (OPDM_E <= -1) THEN OPDM_E = .;
   IF (OPDF_A <= -1) THEN OPDF_A = .;
   IF (OPDF_B <= -1) THEN OPDF_B = .;
   IF (OPDF_C <= -1) THEN OPDF_C = .;
   IF (OPDF_D <= -1) THEN OPDF_D = .;
   IF (OPDF_E <= -1) THEN OPDF_E = .;
   IF (TOTAL_A <= -1) THEN TOTAL_A = .;
   IF (TOTAL_B <= -1) THEN TOTAL_B = .;
   IF (TOTAL_C <= -1) THEN TOTAL_C = .;
   IF (TOTAL_D <= -1) THEN TOTAL_D = .;
   IF (TOTAL_E <= -1) THEN TOTAL_E = .;
   IF (B11 <= -1) THEN B11 = .;
   IF (B12A <= -1) THEN B12A = .;
   IF (B12B <= -1) THEN B12B = .;
   IF (B12C <= -1) THEN B12C = .;
   IF (B12D <= -1) THEN B12D = .;
   IF (B12E <= -1) THEN B12E = .;
   IF (B12F <= -1) THEN B12F = .;
   IF (B12G <= -1) THEN B12G = .;
   IF (B12H <= -1) THEN B12H = .;
   IF (B12I <= -1) THEN B12I = .;
   IF (B12J <= -1) THEN B12J = .;
   IF (B13A <= -1) THEN B13A = .;
   IF (B13B <= -1) THEN B13B = .;
   IF (B13C <= -1) THEN B13C = .;
   IF (B13D <= -1) THEN B13D = .;
   IF (B13E <= -1) THEN B13E = .;
   IF (B13F <= -1) THEN B13F = .;
   IF (B13G <= -1) THEN B13G = .;
   IF (B13H <= -1) THEN B13H = .;
   IF (B13I <= -1) THEN B13I = .;
   IF (B14 <= -1) THEN B14 = .;
   IF (B15A <= -1) THEN B15A = .;
   IF (B15B <= -1) THEN B15B = .;
   IF (B15C <= -1) THEN B15C = .;
   IF (B15D <= -1) THEN B15D = .;
   IF (B15E <= -1) THEN B15E = .;
   IF (B16 <= -1) THEN B16 = .;
   IF (B17 <= -1) THEN B17 = .;
   IF (B18 <= -1) THEN B18 = .;
   IF (FLAG9_A <= -1) THEN FLAG9_A = .;
   IF (FLAG9_B <= -1) THEN FLAG9_B = .;
   IF (FLAG9_C <= -1) THEN FLAG9_C = .;
   IF (FLAG9_D <= -1) THEN FLAG9_D = .;
   IF (FLAG9_E <= -1) THEN FLAG9_E = .;
   IF (FLAG9_F <= -1) THEN FLAG9_F = .;
   IF (FLAG9_G <= -1) THEN FLAG9_G = .;
   IF (FLAG9_H <= -1) THEN FLAG9_H = .;
   IF (FLAG9_I <= -1) THEN FLAG9_I = .;
   IF (FLAG9_J <= -1) THEN FLAG9_J = .;
   IF (FLAG9_K <= -1) THEN FLAG9_K = .;
   IF (FLAG9_L <= -1) THEN FLAG9_L = .;
   IF (FLAG9_M <= -1) THEN FLAG9_M = .;
   IF (FLAG9_N <= -1) THEN FLAG9_N = .;
   IF (FLAG9_O <= -1) THEN FLAG9_O = .;
   IF (FLAG9_P <= -1) THEN FLAG9_P = .;
   IF (B19 <= -1) THEN B19 = .;
   IF (B20A <= -1) THEN B20A = .;
   IF (B20B <= -1) THEN B20B = .;
   IF (B21 <= -1) THEN B21 = .;
   IF (B22 <= -1) THEN B22 = .;
   IF (B23 <= -1) THEN B23 = .;
   IF (B24A <= -1) THEN B24A = .;
   IF (B24B <= -1) THEN B24B = .;
   IF (B24C <= -1) THEN B24C = .;
   IF (B24D <= -1) THEN B24D = .;
   IF (B24E <= -1) THEN B24E = .;
   IF (B25 <= -1) THEN B25 = .;
   IF (B25A <= -1) THEN B25A = .;
   IF (B25B <= -1) THEN B25B = .;
   IF (B25C <= -1) THEN B25C = .;
   IF (B25D <= -1) THEN B25D = .;
   IF (B25E <= -1) THEN B25E = .;
   IF (B25F <= -1) THEN B25F = .;
   IF (B25G <= -1) THEN B25G = .;
   IF (B25H <= -1) THEN B25H = .;
   IF (B26_NO <= -1) THEN B26_NO = .;
   IF (B26_UNIT <= -1) THEN B26_UNIT = .;
   IF (B27_NO <= -1) THEN B27_NO = .;
   IF (B27_UNIT <= -1) THEN B27_UNIT = .;
   IF (B28A <= -1) THEN B28A = .;
   IF (B28B <= -1) THEN B28B = .;
   IF (B28C <= -1) THEN B28C = .;
   IF (B28D <= -1) THEN B28D = .;
   IF (FLAG10_A <= -1) THEN FLAG10_A = .;
   IF (FLAG10_B <= -1) THEN FLAG10_B = .;
   IF (FLAG10_C <= -1) THEN FLAG10_C = .;
   IF (FLAG10_D <= -1) THEN FLAG10_D = .;
   IF (FLAG10_E <= -1) THEN FLAG10_E = .;
   IF (FLAG10_F <= -1) THEN FLAG10_F = .;
   IF (FLAG10_G <= -1) THEN FLAG10_G = .;
   IF (FLAG10_H <= -1) THEN FLAG10_H = .;
   IF (FLAG10_I <= -1) THEN FLAG10_I = .;
   IF (FLAG10_J <= -1) THEN FLAG10_J = .;
   IF (FLAG10_K <= -1) THEN FLAG10_K = .;
   IF (FLAG10_L <= -1) THEN FLAG10_L = .;
   IF (SEQ11 <= -1) THEN SEQ11 = .;
   IF (HIDD_DEM <= -1) THEN HIDD_DEM = .;
   IF (HIDF_DEM <= -1) THEN HIDF_DEM = .;
   IF (RSDD_DEM <= -1) THEN RSDD_DEM = .;
   IF (RSDF_DEM <= -1) THEN RSDF_DEM = .;
   IF (OPDD_DEM <= -1) THEN OPDD_DEM = .;
   IF (OPDM_DEM <= -1) THEN OPDM_DEM = .;
   IF (OPDF_DEM <= -1) THEN OPDF_DEM = .;
   IF (ALC_DEM <= -1) THEN ALC_DEM = .;
   IF (A_WHITE <= -1) THEN A_WHITE = .;
   IF (A_BLACK <= -1) THEN A_BLACK = .;
   IF (A_HISP <= -1) THEN A_HISP = .;
   IF (A_ASIAN <= -1) THEN A_ASIAN = .;
   IF (A_INDIAN <= -1) THEN A_INDIAN = .;
   IF (A_OTHER <= -1) THEN A_OTHER = .;
   IF (B_14 <= -1) THEN B_14 = .;
   IF (B_15 <= -1) THEN B_15 = .;
   IF (B_18 <= -1) THEN B_18 = .;
   IF (B_25 <= -1) THEN B_25 = .;
   IF (B_35 <= -1) THEN B_35 = .;
   IF (B_45 <= -1) THEN B_45 = .;
   IF (B_65 <= -1) THEN B_65 = .;
   IF (C_EMP <= -1) THEN C_EMP = .;
   IF (C_NOTEMP <= -1) THEN C_NOTEMP = .;
   IF (DEMXENV2 <= -1) THEN DEMXENV2 = .;
   IF (SEQ12 <= -1) THEN SEQ12 = .;
   IF (D_HEROIN <= -1) THEN D_HEROIN = .;
   IF (D_CRACK <= -1) THEN D_CRACK = .;
   IF (D_COCAIN <= -1) THEN D_COCAIN = .;
   IF (D_BENZ <= -1) THEN D_BENZ = .;
   IF (D_BARB <= -1) THEN D_BARB = .;
   IF (D_AMPH <= -1) THEN D_AMPH = .;
   IF (D_MARIJ <= -1) THEN D_MARIJ = .;
   IF (D_PCP <= -1) THEN D_PCP = .;
   IF (D_OTH <= -1) THEN D_OTH = .;
   IF (E_NOPAY <= -1) THEN E_NOPAY = .;
   IF (E_SLFPAY <= -1) THEN E_SLFPAY = .;
   IF (E_PRIVTE <= -1) THEN E_PRIVTE = .;
   IF (E_MEDCD <= -1) THEN E_MEDCD = .;
   IF (MEDCR_E <= -1) THEN MEDCR_E = .;
   IF (E_OTHER <= -1) THEN E_OTHER = .;
   IF (METHOD <= -1) THEN METHOD = .;
   IF (C1_BOX <= -1) THEN C1_BOX = .;
   IF (HIDD_C1A <= -1) THEN HIDD_C1A = .;
   IF (HIDD_C1B <= -1) THEN HIDD_C1B = .;
   IF (HIDD_C1C <= -1) THEN HIDD_C1C = .;
   IF (HIDD_C1D <= -1) THEN HIDD_C1D = .;
   IF (HIDD_C1E <= -1) THEN HIDD_C1E = .;
   IF (HIDF_C1A <= -1) THEN HIDF_C1A = .;
   IF (HIDF_C1B <= -1) THEN HIDF_C1B = .;
   IF (HIDF_C1C <= -1) THEN HIDF_C1C = .;
   IF (HIDF_C1D <= -1) THEN HIDF_C1D = .;
   IF (HIDF_C1E <= -1) THEN HIDF_C1E = .;
   IF (RSDD_C1A <= -1) THEN RSDD_C1A = .;
   IF (RSDD_C1B <= -1) THEN RSDD_C1B = .;
   IF (RSDD_C1C <= -1) THEN RSDD_C1C = .;
   IF (RSDD_C1D <= -1) THEN RSDD_C1D = .;
   IF (RSDD_C1E <= -1) THEN RSDD_C1E = .;
   IF (RSDF_C1A <= -1) THEN RSDF_C1A = .;
   IF (RSDF_C1B <= -1) THEN RSDF_C1B = .;
   IF (RSDF_C1C <= -1) THEN RSDF_C1C = .;
   IF (RSDF_C1D <= -1) THEN RSDF_C1D = .;
   IF (RSDF_C1E <= -1) THEN RSDF_C1E = .;
   IF (FLAG13_A <= -1) THEN FLAG13_A = .;
   IF (FLAG13_B <= -1) THEN FLAG13_B = .;
   IF (FLAG13_C <= -1) THEN FLAG13_C = .;
   IF (FLAG13_D <= -1) THEN FLAG13_D = .;
   IF (FLAG13_E <= -1) THEN FLAG13_E = .;
   IF (FLAG13_F <= -1) THEN FLAG13_F = .;
   IF (FLAG13_G <= -1) THEN FLAG13_G = .;
   IF (FLAG13_H <= -1) THEN FLAG13_H = .;
   IF (FLAG13_I <= -1) THEN FLAG13_I = .;
   IF (FLAG13_J <= -1) THEN FLAG13_J = .;
   IF (FLAG13_K <= -1) THEN FLAG13_K = .;
   IF (FLAG13_L <= -1) THEN FLAG13_L = .;
   IF (FLAG13_M <= -1) THEN FLAG13_M = .;
   IF (FLAG13_N <= -1) THEN FLAG13_N = .;
   IF (FLAG13_O <= -1) THEN FLAG13_O = .;
   IF (FLAG13_P <= -1) THEN FLAG13_P = .;
   IF (FLAG13_Q <= -1) THEN FLAG13_Q = .;
   IF (FLAG13_R <= -1) THEN FLAG13_R = .;
   IF (FLAG13_S <= -1) THEN FLAG13_S = .;
   IF (FLAG13_T <= -1) THEN FLAG13_T = .;
   IF (OPDD_C1A <= -1) THEN OPDD_C1A = .;
   IF (OPDD_C1B <= -1) THEN OPDD_C1B = .;
   IF (OPDD_C1C <= -1) THEN OPDD_C1C = .;
   IF (OPDD_C1D <= -1) THEN OPDD_C1D = .;
   IF (OPDD_C1E <= -1) THEN OPDD_C1E = .;
   IF (OPDM_C1A <= -1) THEN OPDM_C1A = .;
   IF (OPDM_C1B <= -1) THEN OPDM_C1B = .;
   IF (OPDM_C1C <= -1) THEN OPDM_C1C = .;
   IF (OPDM_C1D <= -1) THEN OPDM_C1D = .;
   IF (OPDM_C1E <= -1) THEN OPDM_C1E = .;
   IF (OPDF_C1A <= -1) THEN OPDF_C1A = .;
   IF (OPDF_C1B <= -1) THEN OPDF_C1B = .;
   IF (OPDF_C1C <= -1) THEN OPDF_C1C = .;
   IF (OPDF_C1D <= -1) THEN OPDF_C1D = .;
   IF (OPDF_C1E <= -1) THEN OPDF_C1E = .;
   IF (TOT_C1A <= -1) THEN TOT_C1A = .;
   IF (TOT_C1B <= -1) THEN TOT_C1B = .;
   IF (TOT_C1C <= -1) THEN TOT_C1C = .;
   IF (TOT_C1D <= -1) THEN TOT_C1D = .;
   IF (TOT_C1E <= -1) THEN TOT_C1E = .;
   IF (C2 <= -1) THEN C2 = .;
   IF (FLAG14_A <= -1) THEN FLAG14_A = .;
   IF (FLAG14_B <= -1) THEN FLAG14_B = .;
   IF (FLAG14_C <= -1) THEN FLAG14_C = .;
   IF (FLAG14_D <= -1) THEN FLAG14_D = .;
   IF (FLAG14_E <= -1) THEN FLAG14_E = .;
   IF (FLAG14_F <= -1) THEN FLAG14_F = .;
   IF (FLAG14_G <= -1) THEN FLAG14_G = .;
   IF (FLAG14_H <= -1) THEN FLAG14_H = .;
   IF (FLAG14_I <= -1) THEN FLAG14_I = .;
   IF (FLAG14_J <= -1) THEN FLAG14_J = .;
   IF (FLAG14_K <= -1) THEN FLAG14_K = .;
   IF (FLAG14_L <= -1) THEN FLAG14_L = .;
   IF (FLAG14_M <= -1) THEN FLAG14_M = .;
   IF (FLAG14_N <= -1) THEN FLAG14_N = .;
   IF (FLAG14_O <= -1) THEN FLAG14_O = .;
   IF (FLAG14_P <= -1) THEN FLAG14_P = .;
   IF (FLAG14_Q <= -1) THEN FLAG14_Q = .;
   IF (FLAG14_R <= -1) THEN FLAG14_R = .;
   IF (FLAG14_S <= -1) THEN FLAG14_S = .;
   IF (FLAG14_T <= -1) THEN FLAG14_T = .;
   IF (HIDDPNO <= -1) THEN HIDDPNO = .;
   IF (HIDDPUNT <= -1) THEN HIDDPUNT = .;
   IF (HIDDANO <= -1) THEN HIDDANO = .;
   IF (HIDDAUNT <= -1) THEN HIDDAUNT = .;
   IF (HIDFPNO <= -1) THEN HIDFPNO = .;
   IF (HIDFPUNT <= -1) THEN HIDFPUNT = .;
   IF (HIDFANO <= -1) THEN HIDFANO = .;
   IF (HIDFAUNT <= -1) THEN HIDFAUNT = .;
   IF (RSDDPNO <= -1) THEN RSDDPNO = .;
   IF (RSDDPUNT <= -1) THEN RSDDPUNT = .;
   IF (RSDDANO <= -1) THEN RSDDANO = .;
   IF (RSDDAUNT <= -1) THEN RSDDAUNT = .;
   IF (RSDFPNO <= -1) THEN RSDFPNO = .;
   IF (RSDFPUNT <= -1) THEN RSDFPUNT = .;
   IF (RSDFANO <= -1) THEN RSDFANO = .;
   IF (RSDFAUNT <= -1) THEN RSDFAUNT = .;
   IF (OPDDPNO <= -1) THEN OPDDPNO = .;
   IF (OPDDPUNT <= -1) THEN OPDDPUNT = .;
   IF (OPDDANO <= -1) THEN OPDDANO = .;
   IF (OPDDAUNT <= -1) THEN OPDDAUNT = .;
   IF (OPDMPNO <= -1) THEN OPDMPNO = .;
   IF (OPDMPUNT <= -1) THEN OPDMPUNT = .;
   IF (OPDMANO <= -1) THEN OPDMANO = .;
   IF (OPDMAUNT <= -1) THEN OPDMAUNT = .;
   IF (OPDFPNO <= -1) THEN OPDFPNO = .;
   IF (OPDFPUNT <= -1) THEN OPDFPUNT = .;
   IF (OPDFANO <= -1) THEN OPDFANO = .;
   IF (OPDFAUNT <= -1) THEN OPDFAUNT = .;
   IF (C4 <= -1) THEN C4 = .;
   IF (C5 <= -1) THEN C5 = .;
   IF (C6 <= -1) THEN C6 = .;
   IF (C7A <= -1) THEN C7A = .;
   IF (C7B <= -1) THEN C7B = .;
   IF (C7C <= -1) THEN C7C = .;
   IF (C7D <= -1) THEN C7D = .;
   IF (C7E <= -1) THEN C7E = .;
   IF (C7F <= -1) THEN C7F = .;
   IF (C7G <= -1) THEN C7G = .;
   IF (C7H <= -1) THEN C7H = .;
   IF (C7I <= -1) THEN C7I = .;
   IF (C7J <= -1) THEN C7J = .;
   IF (C8A <= -1) THEN C8A = .;
   IF (C8B <= -1) THEN C8B = .;
   IF (C8C <= -1) THEN C8C = .;
   IF (C8D <= -1) THEN C8D = .;
   IF (C9 <= -1) THEN C9 = .;
   IF (C10_REF <= -1) THEN C10_REF = .;
   IF (C11_REF <= -1) THEN C11_REF = .;
   IF (C12_TST <= -1) THEN C12_TST = .;
   IF (C13 <= -1) THEN C13 = .;
   IF (C14 <= -1) THEN C14 = .;
   IF (C16 <= -1) THEN C16 = .;
   IF (C17 <= -1) THEN C17 = .;
   IF (C18A <= -1) THEN C18A = .;
   IF (C18B <= -1) THEN C18B = .;
   IF (C18C <= -1) THEN C18C = .;
   IF (C19A <= -1) THEN C19A = .;
   IF (C19B <= -1) THEN C19B = .;
   IF (C19C <= -1) THEN C19C = .;
   IF (C20A_ADM <= -1) THEN C20A_ADM = .;
   IF (C20A_TRT <= -1) THEN C20A_TRT = .;
   IF (C20A_DIS <= -1) THEN C20A_DIS = .;
   IF (C20B_ADM <= -1) THEN C20B_ADM = .;
   IF (C20B_TRT <= -1) THEN C20B_TRT = .;
   IF (C20B_DIS <= -1) THEN C20B_DIS = .;
   IF (C20C_ADM <= -1) THEN C20C_ADM = .;
   IF (C20C_TRT <= -1) THEN C20C_TRT = .;
   IF (C20C_DIS <= -1) THEN C20C_DIS = .;
   IF (C20D_ADM <= -1) THEN C20D_ADM = .;
   IF (C20D_TRT <= -1) THEN C20D_TRT = .;
   IF (C20D_DIS <= -1) THEN C20D_DIS = .;
   IF (C20E_ADM <= -1) THEN C20E_ADM = .;
   IF (C20E_TRT <= -1) THEN C20E_TRT = .;
   IF (C20E_DIS <= -1) THEN C20E_DIS = .;
   IF (C20F_ADM <= -1) THEN C20F_ADM = .;
   IF (C20F_TRT <= -1) THEN C20F_TRT = .;
   IF (C20F_DIS <= -1) THEN C20F_DIS = .;
   IF (C20G_ADM <= -1) THEN C20G_ADM = .;
   IF (C20G_TRT <= -1) THEN C20G_TRT = .;
   IF (C20G_DIS <= -1) THEN C20G_DIS = .;
   IF (C20H_ADM <= -1) THEN C20H_ADM = .;
   IF (C20H_TRT <= -1) THEN C20H_TRT = .;
   IF (C20H_DIS <= -1) THEN C20H_DIS = .;
   IF (C20I_ADM <= -1) THEN C20I_ADM = .;
   IF (C20I_TRT <= -1) THEN C20I_TRT = .;
   IF (C20I_DIS <= -1) THEN C20I_DIS = .;
   IF (C21 <= -1) THEN C21 = .;
   IF (C22_NO <= -1) THEN C22_NO = .;
   IF (C22_UNIT <= -1) THEN C22_UNIT = .;
   IF (C23 <= -1) THEN C23 = .;
   IF (C24 <= -1) THEN C24 = .;
   IF (C25 <= -1) THEN C25 = .;
   IF (C26 <= -1) THEN C26 = .;
   IF (C27A <= -1) THEN C27A = .;
   IF (C27B <= -1) THEN C27B = .;
   IF (C27C <= -1) THEN C27C = .;
   IF (C27D <= -1) THEN C27D = .;
   IF (C27E <= -1) THEN C27E = .;
   IF (C27F <= -1) THEN C27F = .;
   IF (C27G <= -1) THEN C27G = .;
   IF (C27H <= -1) THEN C27H = .;
   IF (C27I <= -1) THEN C27I = .;
   IF (C27J <= -1) THEN C27J = .;
   IF (C27K <= -1) THEN C27K = .;
   IF (C27L <= -1) THEN C27L = .;
   IF (D1_BOX <= -1) THEN D1_BOX = .;
   IF (HIDD_D1 <= -1) THEN HIDD_D1 = .;
   IF (HIDF_D1 <= -1) THEN HIDF_D1 = .;
   IF (RSDD_D1 <= -1) THEN RSDD_D1 = .;
   IF (RSDF_D1 <= -1) THEN RSDF_D1 = .;
   IF (OPDD_D1 <= -1) THEN OPDD_D1 = .;
   IF (OPDM_D1 <= -1) THEN OPDM_D1 = .;
   IF (OPDF_D1 <= -1) THEN OPDF_D1 = .;
   IF (TOTAL_D1 <= -1) THEN TOTAL_D1 = .;
   IF (D2 <= -1) THEN D2 = .;
   IF (FLAG17_A <= -1) THEN FLAG17_A = .;
   IF (D3 <= -1) THEN D3 = .;
   IF (D4 <= -1) THEN D4 = .;
   IF (D5 <= -1) THEN D5 = .;
   IF (D6 <= -1) THEN D6 = .;
   IF (D7A <= -1) THEN D7A = .;
   IF (D7B <= -1) THEN D7B = .;
   IF (D7C <= -1) THEN D7C = .;
   IF (D7D <= -1) THEN D7D = .;
   IF (D7E <= -1) THEN D7E = .;
   IF (D7F <= -1) THEN D7F = .;
   IF (D7G <= -1) THEN D7G = .;
   IF (D7H <= -1) THEN D7H = .;
   IF (D7I <= -1) THEN D7I = .;
   IF (D7J <= -1) THEN D7J = .;
   IF (D7K <= -1) THEN D7K = .;
   IF (D7L <= -1) THEN D7L = .;
   IF (KEYBATCH <= -1) THEN KEYBATCH = .;
   IF (FLAG18_A <= -1) THEN FLAG18_A = .;
   IF (FLAG18_B <= -1) THEN FLAG18_B = .;
   IF (FLAG18_C <= -1) THEN FLAG18_C = .;
   IF (FLAG18_D <= -1) THEN FLAG18_D = .;
   IF (FLAG18_E <= -1) THEN FLAG18_E = .;
   IF (FLAG18_F <= -1) THEN FLAG18_F = .;
   IF (FLAG18_G <= -1) THEN FLAG18_G = .;
   IF (FLAG18_H <= -1) THEN FLAG18_H = .;
   IF (FLAG18_I <= -1) THEN FLAG18_I = .;
   IF (FLAG18_J <= -1) THEN FLAG18_J = .;
   IF (FLAG18_K <= -1) THEN FLAG18_K = .;
   IF (FLAG18_L <= -1) THEN FLAG18_L = .;
   IF (FLAG18_M <= -1) THEN FLAG18_M = .;
   IF (NFINWT0 <= -1.000000) THEN NFINWT0 = .;
   IF (RPWT1 <= -1.000000) THEN RPWT1 = .;
   IF (RPWT2 <= -1.000000) THEN RPWT2 = .;
   IF (RPWT3 <= -1.000000) THEN RPWT3 = .;
   IF (RPWT4 <= -1.000000) THEN RPWT4 = .;
   IF (RPWT5 <= -1.000000) THEN RPWT5 = .;
   IF (RPWT6 <= -1.000000) THEN RPWT6 = .;
   IF (RPWT7 <= -1.000000) THEN RPWT7 = .;
   IF (RPWT8 <= -1.000000) THEN RPWT8 = .;
   IF (RPWT9 <= -1.000000) THEN RPWT9 = .;
   IF (RPWT10 <= -1.000000) THEN RPWT10 = .;
   IF (RPWT11 <= -1.000000) THEN RPWT11 = .;
   IF (RPWT12 <= -1.000000) THEN RPWT12 = .;
   IF (RPWT13 <= -1.000000) THEN RPWT13 = .;
   IF (RPWT14 <= -1.000000) THEN RPWT14 = .;
   IF (RPWT15 <= -1.000000) THEN RPWT15 = .;
   IF (RPWT16 <= -1.000000) THEN RPWT16 = .;
   IF (RPWT17 <= -1.000000) THEN RPWT17 = .;
   IF (RPWT18 <= -1.000000) THEN RPWT18 = .;
   IF (RPWT19 <= -1.000000) THEN RPWT19 = .;
   IF (RPWT20 <= -1.000000) THEN RPWT20 = .;
   IF (RPWT21 <= -1.000000) THEN RPWT21 = .;
   IF (RPWT22 <= -1.000000) THEN RPWT22 = .;
   IF (RPWT23 <= -1.000000) THEN RPWT23 = .;
   IF (RPWT24 <= -1.000000) THEN RPWT24 = .;
   IF (RPWT25 <= -1.000000) THEN RPWT25 = .;
   IF (RPWT26 <= -1.000000) THEN RPWT26 = .;
   IF (RPWT27 <= -1.000000) THEN RPWT27 = .;
   IF (RPWT28 <= -1.000000) THEN RPWT28 = .;
   IF (RPWT29 <= -1.000000) THEN RPWT29 = .;
   IF (RPWT30 <= -1.000000) THEN RPWT30 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT OBS_NUM obs_num. CRP_MO1 crp_mo1f. CRP_DA1 crp_da1f.
         CRP_YR1 crp_yr1f. CRP_MO2 crp_mo2f. CRP_DA2 crp_da2f.
         CRP_YR2 crp_yr2f. CLENGTH clength. FRP_MO1 frp_mo1f.
         FRP_DA1 frp_da1f. FRP_YR1 frp_yr1f. FRP_MO2 frp_mo2f.
         FRP_DA2 frp_da2f. FRP_YR2 frp_yr2f. FLENGTH flength.
         A1_NO a1_no. A1_UNIT a1_unit. A2A a2a.
         A2B a2b. A2C a2c. A2D a2d.
         A2E a2e. A3A a3a. A3B a3b.
         A3C a3c. A3D a3d. A3E a3e.
         A4A a4a. A4B a4b. A4C a4c.
         A4D a4d. A4E a4e. A4F a4f.
         A5A a5a. A5B a5b. HIDD_A6 hidd_a6f.
         HIDM_A6 hidm_a6f. HIDF_A6 hidf_a6f. RSDD_A6 rsdd_a6f.
         RSDM_A6 rsdm_a6f. RSDF_A6 rsdf_a6f. OPDD_A6 opdd_a6f.
         OPDM_A6 opdm_a6f. OPDF_A6 opdf_a6f. ALC_A6 alc_a6ff.
         CORRFAC corrfac. ALCHONLY alchonly. SEQ11CNT seq11cnt.
         SEQ12CNT seq12cnt. NUMMOD nummod. MOD mod.
         OWN own. ENV env. XENV xenv.
         STRATUM stratum. REGION region. IMPFLAG impflag.
         A7_BOX a7_box. A7A_FT a7a_ft. A7A_PT a7a_pt.
         A7A_CON a7a_con. A7A_CERT a7a_cert. A7B_FT a7b_ft.
         A7B_PT a7b_pt. A7B_CON a7b_con. A7B_CERT a7b_cert.
         A7C_FT a7c_ft. A7C_PT a7c_pt. A7C_CON a7c_con.
         A7C_CERT a7c_cert. A7D_FT a7d_ft. A7D_PT a7d_pt.
         A7D_CON a7d_con. A7D_CERT a7d_cert. A7E_FT a7e_ft.
         A7E_PT a7e_pt. A7E_CON a7e_con. A7E_CERT a7e_cert.
         A7F_FT a7f_ft. A7F_PT a7f_pt. A7F_CON a7f_con.
         A7F_CERT a7f_cert. A7G_FT a7g_ft. A7G_PT a7g_pt.
         A7G_CON a7g_con. A7G_CERT a7g_cert. A7H_FT a7h_ft.
         A7H_PT a7h_pt. A7H_CON a7h_con. A7H_CERT a7h_cert.
         A7I_FT a7i_ft. A7I_PT a7i_pt. A7I_CON a7i_con.
         A7I_CERT a7i_cert. A7J_FT a7j_ft. A7J_PT a7j_pt.
         A7J_CON a7j_con. A7J_CERT a7j_cert. A7K_FT a7k_ft.
         A7K_PT a7k_pt. A7K_CON a7k_con. A7K_CERT a7k_cert.
         A7L_FT a7l_ft. A7L_PT a7l_pt. A7L_CON a7l_con.
         A7L_CERT a7l_cert. A7M_FT a7m_ft. A7M_PT a7m_pt.
         A7M_CON a7m_con. A7M_CERT a7m_cert. A8 a8ffffff.
         A9 a9ffffff. A10 a10fffff. A11 a11fffff.
         B1_BOX b1_box. HIDDMCAP hiddmcap. HIDDFCAP hiddfcap.
         HIDDTCAP hiddtcap. HIDDMACT hiddmact. HIDDFACT hiddfact.
         HIDDTACT hiddtact. HIDFMCAP hidfmcap. HIDFFCAP hidffcap.
         HIDFTCAP hidftcap. HIDFMACT hidfmact. HIDFFACT hidffact.
         HIDFTACT hidftact. RSDDMCAP rsddmcap. RSDDFCAP rsddfcap.
         RSDDTCAP rsddtcap. RSDDMACT rsddmact. RSDDFACT rsddfact.
         RSDDTACT rsddtact. RSDFMCAP rsdfmcap. RSDFFCAP rsdffcap.
         RSDFTCAP rsdftcap. RSDFMACT rsdfmact. RSDFFACT rsdffact.
         RSDFTACT rsdftact. FLAG4_A flag4_a. FLAG4_B flag4_b.
         FLAG4_C flag4_c. FLAG4_D flag4_d. FLAG4_E flag4_e.
         FLAG4_F flag4_f. FLAG4_G flag4_g. FLAG4_H flag4_h.
         FLAG4_I flag4_i. FLAG4_J flag4_j. FLAG4_K flag4_k.
         FLAG4_L flag4_l. FLAG4_M flag4_m. FLAG4_N flag4_n.
         FLAG4_O flag4_o. FLAG4_P flag4_p. OPDDMCAP opddmcap.
         OPDDFCAP opddfcap. OPDDTCAP opddtcap. OPDDMACT opddmact.
         OPDDFACT opddfact. OPDDTACT opddtact. OPDMMCAP opdmmcap.
         OPDMFCAP opdmfcap. OPDMTCAP opdmtcap. OPDMMACT opdmmact.
         OPDMFACT opdmfact. OPDMTACT opdmtact. OPDFMCAP opdfmcap.
         OPDFFCAP opdffcap. OPDFTCAP opdftcap. OPDFMACT opdfmact.
         OPDFFACT opdffact. OPDFTACT opdftact. FLAG5_A flag5_a.
         FLAG5_B flag5_b. FLAG5_C flag5_c. FLAG5_D flag5_d.
         FLAG5_E flag5_e. FLAG5_F flag5_f. FLAG5_G flag5_g.
         FLAG5_H flag5_h. FLAG5_I flag5_i. FLAG5_J flag5_j.
         FLAG5_K flag5_k. FLAG5_L flag5_l. ALCMCAP alcmcap.
         ALCFCAP alcfcap. ALCTCAP alctcap. ALCMACT alcmact.
         ALCFACT alcfact. ALCTACT alctact. TOTMCAP totmcap.
         TOTFCAP totfcap. TOTALCAP totalcap. TOTMACT totmact.
         TOTFACT totfact. TOTALACT totalact. B2 b2ffffff.
         B3 b3ffffff. B4_NO b4_no. B4_UNIT b4_unit.
         B5 b5ffffff. B6 b6ffffff. B7 b7ffffff.
         B8 b8ffffff. B9A b9a. B9B b9b.
         WAITTIME waittime. FLAG6_A flag6_a. FLAG6_B flag6_b.
         FLAG6_C flag6_c. FLAG6_D flag6_d. FLAG6_E flag6_e.
         FLAG6_F flag6_f. FLAG6_G flag6_g. FLAG6_H flag6_h.
         B10_BOX b10_box. HIDD_A hidd_a. HIDD_B hidd_b.
         HIDD_C hidd_c. HIDD_D hidd_d. HIDD_E hidd_e.
         HIDF_A hidf_a. HIDF_B hidf_b. HIDF_C hidf_c.
         HIDF_D hidf_d. HIDF_E hidf_e. RSDD_A rsdd_a.
         RSDD_B rsdd_b. RSDD_C rsdd_c. RSDD_D rsdd_d.
         RSDD_E rsdd_e. RSDF_A rsdf_a. RSDF_B rsdf_b.
         RSDF_C rsdf_c. RSDF_D rsdf_d. RSDF_E rsdf_e.
         OPDD_A opdd_a. OPDD_B opdd_b. OPDD_C opdd_c.
         OPDD_D opdd_d. OPDD_E opdd_e. OPDM_A opdm_a.
         OPDM_B opdm_b. OPDM_C opdm_c. OPDM_D opdm_d.
         OPDM_E opdm_e. OPDF_A opdf_a. OPDF_B opdf_b.
         OPDF_C opdf_c. OPDF_D opdf_d. OPDF_E opdf_e.
         TOTAL_A total_a. TOTAL_B total_b. TOTAL_C total_c.
         TOTAL_D total_d. TOTAL_E total_e. B11 b11fffff.
         B12A b12a. B12B b12b. B12C b12c.
         B12D b12d. B12E b12e. B12F b12f.
         B12G b12g. B12H b12h. B12I b12i.
         B12J b12j. B13A b13a. B13B b13b.
         B13C b13c. B13D b13d. B13E b13e.
         B13F b13f. B13G b13g. B13H b13h.
         B13I b13i. B14 b14fffff. B15A b15a.
         B15B b15b. B15C b15c. B15D b15d.
         B15E b15e. B16 b16fffff. B17 b17fffff.
         B18 b18fffff. FLAG9_A flag9_a. FLAG9_B flag9_b.
         FLAG9_C flag9_c. FLAG9_D flag9_d. FLAG9_E flag9_e.
         FLAG9_F flag9_f. FLAG9_G flag9_g. FLAG9_H flag9_h.
         FLAG9_I flag9_i. FLAG9_J flag9_j. FLAG9_K flag9_k.
         FLAG9_L flag9_l. FLAG9_M flag9_m. FLAG9_N flag9_n.
         FLAG9_O flag9_o. FLAG9_P flag9_p. B19 b19fffff.
         B20A b20a. B20B b20b. B21 b21fffff.
         B22 b22fffff. B23 b23fffff. B24A b24a.
         B24B b24b. B24C b24c. B24D b24d.
         B24E b24e. B25 b25fffff. B25A b25a.
         B25B b25b. B25C b25c. B25D b25d.
         B25E b25e. B25F b25f. B25G b25g.
         B25H b25h. B26_NO b26_no. B26_UNIT b26_unit.
         B27_NO b27_no. B27_UNIT b27_unit. B28A b28a.
         B28B b28b. B28C b28c. B28D b28d.
         FLAG10_A flag10_a. FLAG10_B flag10_b. FLAG10_C flag10_c.
         FLAG10_D flag10_d. FLAG10_E flag10_e. FLAG10_F flag10_f.
         FLAG10_G flag10_g. FLAG10_H flag10_h. FLAG10_I flag10_i.
         FLAG10_J flag10_j. FLAG10_K flag10_k. FLAG10_L flag10_l.
         SEQ11 seq11fff. HIDD_DEM hidd_dem. HIDF_DEM hidf_dem.
         RSDD_DEM rsdd_dem. RSDF_DEM rsdf_dem. OPDD_DEM opdd_dem.
         OPDM_DEM opdm_dem. OPDF_DEM opdf_dem. ALC_DEM alc_dem.
         A_WHITE a_white. A_BLACK a_black. A_HISP a_hisp.
         A_ASIAN a_asian. A_INDIAN a_indian. A_OTHER a_other.
         B_14 b_14ffff. B_15 b_15ffff. B_18 b_18ffff.
         B_25 b_25ffff. B_35 b_35ffff. B_45 b_45ffff.
         B_65 b_65ffff. C_EMP c_emp. C_NOTEMP c_notemp.
         DEMXENV2 demxenvf. SEQ12 seq12fff. D_HEROIN d_heroin.
         D_CRACK d_crack. D_COCAIN d_cocain. D_BENZ d_benz.
         D_BARB d_barb. D_AMPH d_amph. D_MARIJ d_marij.
         D_PCP d_pcp. D_OTH d_oth. E_NOPAY e_nopay.
         E_SLFPAY e_slfpay. E_PRIVTE e_privte. E_MEDCD e_medcd.
         MEDCR_E medcr_e. E_OTHER e_other. METHOD method.
         C1_BOX c1_box. HIDD_C1A hidd_c1a. HIDD_C1B hidd_c1b.
         HIDD_C1C hidd_c1c. HIDD_C1D hidd_c1d. HIDD_C1E hidd_c1e.
         HIDF_C1A hidf_c1a. HIDF_C1B hidf_c1b. HIDF_C1C hidf_c1c.
         HIDF_C1D hidf_c1d. HIDF_C1E hidf_c1e. RSDD_C1A rsdd_c1a.
         RSDD_C1B rsdd_c1b. RSDD_C1C rsdd_c1c. RSDD_C1D rsdd_c1d.
         RSDD_C1E rsdd_c1e. RSDF_C1A rsdf_c1a. RSDF_C1B rsdf_c1b.
         RSDF_C1C rsdf_c1c. RSDF_C1D rsdf_c1d. RSDF_C1E rsdf_c1e.
         FLAG13_A flag13_a. FLAG13_B flag13_b. FLAG13_C flag13_c.
         FLAG13_D flag13_d. FLAG13_E flag13_e. FLAG13_F flag13_f.
         FLAG13_G flag13_g. FLAG13_H flag13_h. FLAG13_I flag13_i.
         FLAG13_J flag13_j. FLAG13_K flag13_k. FLAG13_L flag13_l.
         FLAG13_M flag13_m. FLAG13_N flag13_n. FLAG13_O flag13_o.
         FLAG13_P flag13_p. FLAG13_Q flag13_q. FLAG13_R flag13_r.
         FLAG13_S flag13_s. FLAG13_T flag13_t. OPDD_C1A opdd_c1a.
         OPDD_C1B opdd_c1b. OPDD_C1C opdd_c1c. OPDD_C1D opdd_c1d.
         OPDD_C1E opdd_c1e. OPDM_C1A opdm_c1a. OPDM_C1B opdm_c1b.
         OPDM_C1C opdm_c1c. OPDM_C1D opdm_c1d. OPDM_C1E opdm_c1e.
         OPDF_C1A opdf_c1a. OPDF_C1B opdf_c1b. OPDF_C1C opdf_c1c.
         OPDF_C1D opdf_c1d. OPDF_C1E opdf_c1e. TOT_C1A tot_c1a.
         TOT_C1B tot_c1b. TOT_C1C tot_c1c. TOT_C1D tot_c1d.
         TOT_C1E tot_c1e. C2 c2ffffff. FLAG14_A flag14_a.
         FLAG14_B flag14_b. FLAG14_C flag14_c. FLAG14_D flag14_d.
         FLAG14_E flag14_e. FLAG14_F flag14_f. FLAG14_G flag14_g.
         FLAG14_H flag14_h. FLAG14_I flag14_i. FLAG14_J flag14_j.
         FLAG14_K flag14_k. FLAG14_L flag14_l. FLAG14_M flag14_m.
         FLAG14_N flag14_n. FLAG14_O flag14_o. FLAG14_P flag14_p.
         FLAG14_Q flag14_q. FLAG14_R flag14_r. FLAG14_S flag14_s.
         FLAG14_T flag14_t. HIDDPNO hiddpno. HIDDPUNT hiddpunt.
         HIDDANO hiddano. HIDDAUNT hiddaunt. HIDFPNO hidfpno.
         HIDFPUNT hidfpunt. HIDFANO hidfano. HIDFAUNT hidfaunt.
         RSDDPNO rsddpno. RSDDPUNT rsddpunt. RSDDANO rsddano.
         RSDDAUNT rsddaunt. RSDFPNO rsdfpno. RSDFPUNT rsdfpunt.
         RSDFANO rsdfano. RSDFAUNT rsdfaunt. OPDDPNO opddpno.
         OPDDPUNT opddpunt. OPDDANO opddano. OPDDAUNT opddaunt.
         OPDMPNO opdmpno. OPDMPUNT opdmpunt. OPDMANO opdmano.
         OPDMAUNT opdmaunt. OPDFPNO opdfpno. OPDFPUNT opdfpunt.
         OPDFANO opdfano. OPDFAUNT opdfaunt. C4 c4ffffff.
         C5 c5ffffff. C6 c6ffffff. C7A c7a.
         C7B c7b. C7C c7c. C7D c7d.
         C7E c7e. C7F c7f. C7G c7g.
         C7H c7h. C7I c7i. C7J c7j.
         C8A c8a. C8B c8b. C8C c8c.
         C8D c8d. C9 c9ffffff. C10_REF c10_ref.
         C11_REF c11_ref. C12_TST c12_tst. C13 c13fffff.
         C14 c14fffff. C16 c16fffff. C17 c17fffff.
         C18A c18a. C18B c18b. C18C c18c.
         C19A c19a. C19B c19b. C19C c19c.
         C20A_ADM c20a_adm. C20A_TRT c20a_trt. C20A_DIS c20a_dis.
         C20B_ADM c20b_adm. C20B_TRT c20b_trt. C20B_DIS c20b_dis.
         C20C_ADM c20c_adm. C20C_TRT c20c_trt. C20C_DIS c20c_dis.
         C20D_ADM c20d_adm. C20D_TRT c20d_trt. C20D_DIS c20d_dis.
         C20E_ADM c20e_adm. C20E_TRT c20e_trt. C20E_DIS c20e_dis.
         C20F_ADM c20f_adm. C20F_TRT c20f_trt. C20F_DIS c20f_dis.
         C20G_ADM c20g_adm. C20G_TRT c20g_trt. C20G_DIS c20g_dis.
         C20H_ADM c20h_adm. C20H_TRT c20h_trt. C20H_DIS c20h_dis.
         C20I_ADM c20i_adm. C20I_TRT c20i_trt. C20I_DIS c20i_dis.
         C21 c21fffff. C22_NO c22_no. C22_UNIT c22_unit.
         C23 c23fffff. C24 c24fffff. C25 c25fffff.
         C26 c26fffff. C27A c27a. C27B c27b.
         C27C c27c. C27D c27d. C27E c27e.
         C27F c27f. C27G c27g. C27H c27h.
         C27I c27i. C27J c27j. C27K c27k.
         C27L c27l. D1_BOX d1_box. HIDD_D1 hidd_d1f.
         HIDF_D1 hidf_d1f. RSDD_D1 rsdd_d1f. RSDF_D1 rsdf_d1f.
         OPDD_D1 opdd_d1f. OPDM_D1 opdm_d1f. OPDF_D1 opdf_d1f.
         TOTAL_D1 total_df. D2 d2ffffff. FLAG17_A flag17_a.
         D3 d3ffffff. D4 d4ffffff. D5 d5ffffff.
         D6 d6ffffff. D7A d7a. D7B d7b.
         D7C d7c. D7D d7d. D7E d7e.
         D7F d7f. D7G d7g. D7H d7h.
         D7I d7i. D7J d7j. D7K d7k.
         D7L d7l. KEYBATCH keybatch. FLAG18_A flag18_a.
         FLAG18_B flag18_b. FLAG18_C flag18_c. FLAG18_D flag18_d.
         FLAG18_E flag18_e. FLAG18_F flag18_f. FLAG18_G flag18_g.
         FLAG18_H flag18_h. FLAG18_I flag18_i. FLAG18_J flag18_j.
         FLAG18_K flag18_k. FLAG18_L flag18_l. FLAG18_M flag18_m.
         NFINWT0 nfinwt0f. RPWT1 rpwt1fff. RPWT2 rpwt2fff.
         RPWT3 rpwt3fff. RPWT4 rpwt4fff. RPWT5 rpwt5fff.
         RPWT6 rpwt6fff. RPWT7 rpwt7fff. RPWT8 rpwt8fff.
         RPWT9 rpwt9fff. RPWT10 rpwt10ff. RPWT11 rpwt11ff.
         RPWT12 rpwt12ff. RPWT13 rpwt13ff. RPWT14 rpwt14ff.
         RPWT15 rpwt15ff. RPWT16 rpwt16ff. RPWT17 rpwt17ff.
         RPWT18 rpwt18ff. RPWT19 rpwt19ff. RPWT20 rpwt20ff.
         RPWT21 rpwt21ff. RPWT22 rpwt22ff. RPWT23 rpwt23ff.
         RPWT24 rpwt24ff. RPWT25 rpwt25ff. RPWT26 rpwt26ff.
         RPWT27 rpwt27ff. RPWT28 rpwt28ff. RPWT29 rpwt29ff.
         RPWT30 rpwt30ff.  ;
*/

RUN ;
